@@ -915,18 +915,26 @@ class ConfigWidgetAscii : public KstDataSourceConfigWidget {
       } else {
         _ac->_whitespace->setChecked(true);
       }
-      bool hasInstance = _instance != 0L;
       _ac->_indexVector->clear();
+
+      bool hasInstance = _instance != 0L;
       if (hasInstance) {
         _ac->_indexVector->insertStringList(_instance->fieldList());
         KstSharedPtr<AsciiSource> src = kst_cast<AsciiSource>(_instance);
-        assert(src);
-        _ac->_indexType->setCurrentItem(src->_config->_indexInterpretation - 1);
-        if (_instance->fieldList().contains(src->_config->_indexVector)) {
-          _ac->_indexVector->setCurrentText(src->_config->_indexVector);
+        if (src) {
+          _ac->_indexType->setCurrentItem(src->_config->_indexInterpretation - 1);
+          if (_instance->fieldList().contains(src->_config->_indexVector)) {
+            _ac->_indexVector->setCurrentText(src->_config->_indexVector);
+          }
+          _cfg->setGroup(src->fileName());
+        } else {
+          //
+          // consider the case where this datasource is 
+          //  wrapped by the stdin datasource...
+          //
+          _cfg->setGroup("ASCII Other");
         }
 
-        _cfg->setGroup(src->fileName());
         _ac->_delimiters->setText(_cfg->readEntry("Comment Delimiters", _ac->_delimiters->text()));
         _ac->_columnDelimiter->setText(_cfg->readEntry("Column Delimiter", _ac->_columnDelimiter->text()));
         _ac->_columnWidth->setValue(_cfg->readNumEntry("Column Width", _ac->_columnWidth->value()));
@@ -961,6 +969,12 @@ class ConfigWidgetAscii : public KstDataSourceConfigWidget {
       KstSharedPtr<AsciiSource> src = kst_cast<AsciiSource>(_instance);
       if (src) {
         _cfg->setGroup(src->fileName());
+      } else if (_instance) {
+          //
+          // consider the case where this datasource is 
+          //  wrapped by the stdin datasource...
+          //
+        _cfg->setGroup("ASCII Other");
       }
       _cfg->writeEntry("Default INDEX Interpretation", 1 + _ac->_indexType->currentItem());
       _cfg->writeEntry("Comment Delimiters", _ac->_delimiters->text());
