@@ -7,6 +7,18 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
+/* NOTICE (2008-11-15):  This version of GetData has been deprecated, and
+ * fully superseded by the GetData Project:
+ *
+ *   http://getdata.sourceforge.net/
+ *
+ * This version of GetData has known database-corrupting bugs in its
+ * implementation of PutData (which is not used by kst).
+ *
+ * -DVW
+ */
+
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -18,8 +30,8 @@
 #include <string.h>
 #include <math.h>
 
-#include "getdata.h"
-#include "getdata_struct.h"
+#include "old_getdata.h"
+#include "old_getdata_struct.h"
 
 #define DIRFILE_DEBUG 0
 
@@ -2179,6 +2191,9 @@ int GetNFrames(const char *filename_in, int *error_code, const char *in_field) {
   struct stat statbuf;
   int nf;
 
+  /* remove compiler warning about unused parameter */
+  if (in_field) { };
+
   *error_code = SetGetDataError(GD_E_OK, 0, NULL, 0, NULL);
 
   if (first_time) {
@@ -2664,5 +2679,4 @@ int PutData(const char *filename_in, const char *field_code,
 
   return(n_write);
 }
-/* vim: ts=2 sw=2 et
-*/
+
