@@ -25,6 +25,7 @@
 #include <qdir.h>
 #include <qfile.h>
 
+//#define PIOLIBDEBUG
 
 DMCSource::DMCSource(KConfig *cfg, const QString& filename)
 : KstDataSource(cfg, filename, "PLANCK DMC I/O") {
@@ -41,12 +42,16 @@ DMCSource::DMCSource(KConfig *cfg, const QString& filename)
     update();
     _valid = true;
   }
-  //kdDebug() << "Planck source " << (void*)this << " created" << endl;
+#ifdef PIOLIBDEBUG
+  kdDebug() << "Planck source " << (void*)this << " created" << endl;
+#endif
 }
 
 
 DMCSource::~DMCSource() {
-  //kdDebug() << "Planck source " << (void*)this << " destroyed" << endl;
+#ifdef PIOLIBDEBUG
+  kdDebug() << "Planck source " << (void*)this << " destroyed" << endl;
+#endif
 }
 
 
@@ -64,6 +69,7 @@ bool DMCSource::reset() {
     update();
     _valid = true;
   }
+
   return _valid;
 }
 
@@ -72,16 +78,22 @@ KstObject::UpdateType DMCSource::update(int u) {
   if (KstObject::checkUpdateCounter(u)) {
     return lastUpdateResult();
   }
+
   if (_valid && _dmcObject && _dmcObject->updated()) {
     updateNumFramesScalar();
+
     return setLastUpdateResult(KstObject::UPDATE);
   }
+
   return setLastUpdateResult(KstObject::NO_CHANGE);
 }
 
 
-int DMCSource::readField(double *v, const QString& field, int s, int n) {
-  //kdDebug() << "Planck read field " << field << " - " << n << " samples from " << s << endl;
+KstFrameSize DMCSource::readFieldLarge(double *v, const QString& field, KstFrameSize s, KstFrameSize n) {
+#ifdef PIOLIBDEBUG
+  kdDebug() << "Planck read field " << field << " - " << n << " samples from " << s << endl;
+#endif
+
   if (field.lower() == "index") {
     if (n < 0) {
       v[0] = double(s);
@@ -94,15 +106,17 @@ int DMCSource::readField(double *v, const QString& field, int s, int n) {
   }
 
   if (!_valid || !_dmcObject || !_dmcObject->isValid()) {
+#ifdef PIOLIBDEBUG
     kdDebug() << "tried to read from an invalid planck dmc source" << endl;
     kdDebug() << "plugin is valid? " << _valid << endl;
     kdDebug() << "Object object is non-null? " << (_dmcObject.data() != 0) << endl;
+#endif
+
     return -1;
   }
 
-  QSize sz = _dmcObject->range(field);
-  long start = sz.width(), end = sz.height();
-  long count = end - start + 1;
+  DMCRange rng = _dmcObject->range(field);
+  PIOLONG count = rng.lastIndex - rng.firstIndex + 1;
 
   if (s >= count) { // start past the end
     return 0;
@@ -116,17 +130,21 @@ int DMCSource::readField(double *v, const QString& field, int s, int n) {
     n = count - s;
   }
 
-  if (s + start > end) {
-    kdDebug() << "Nothing to read: (" << start << "," << end << ") " << s << endl;
+  if (s + rng.firstIndex > rng.lastIndex) {
+#ifdef PIOLIBDEBUG
+    kdDebug() << "Nothing to read: (" << rng.firstIndex << "," << rng.lastIndex << ") " << s << endl;
+#endif
+
     return 0;
   }
 
   assert(n != 0);
-  return _dmcObject->readObject(field, v, start + s, start + s + n - 1);
+
+  return _dmcObject->readObject(field, v, rng.firstIndex + s, rng.firstIndex + s + n - 1);
 }
 
 
-int DMCSource::readField(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead) {
+KstFrameSize DMCSource::readFieldLargeSkip(double *v, const QString& field, KstFrameSize s, KstFrameSize n, int skip, KstFrameSize *lastFrameRead) {
   if (*lastFrameRead) {
     *lastFrameRead = -1;
   }
@@ -137,14 +155,18 @@ int DMCSource::readField(double *v, const QString& field, int s, int n, int skip
       if (*lastFrameRead) {
         *lastFrameRead = -1; // FIXME
       }
+
       return 1;
     }
+
     for (int i = 0; i < n; ++i) {
       v[i] = double(s + i*skip);
     }
+
     if (*lastFrameRead) {
       *lastFrameRead = -1; // FIXME
     }
+
     return n > 0 ? n : 0;
   }
 
@@ -152,9 +174,8 @@ int DMCSource::readField(double *v, const QString& field, int s, int n, int skip
     return -1;
   }
 
-  QSize sz = _dmcObject->range(field);
-  long start = sz.width(), end = sz.height();
-  long count = end - start + 1;
+  DMCRange rng = _dmcObject->range(field);
+  PIOLONG count = rng.lastIndex - rng.firstIndex + 1;
 
   if (s >= count) { // start past the end
     return 0;
@@ -165,27 +186,37 @@ int DMCSource::readField(double *v, const QString& field, int s, int n, int skip
   }
 
   if (s + (n-1)*skip >= count) { // trying to read past the end
+#ifdef PIOLIBDEBUG
     kdDebug() << "TRYING TO READ PAST END.  n=" << n << endl;
-    // n = ceil((count-s)/skip)
+#endif
     if ((count - s) % skip == 0) {
       n = (count - s) / skip;
     } else {
       n = (count - s) / skip + 1;
     }
+#ifdef PIOLIBDEBUG
     kdDebug() << "N IS NOW=" << n << endl;
+#endif
   }
 
-  if (s + start > end) {
-    kdDebug() << "Nothing to read: (" << start << "," << end << ") " << s << endl;
+  if (s + rng.firstIndex > rng.lastIndex) {
+#ifdef PIOLIBDEBUG
+    kdDebug() << "Nothing to read: (" << rng.firstIndex << "," << rng.lastIndex << ") " << s << endl;
+#endif
+
     return 0;
   }
 
   // PIOLib doesn't have a mechanism to read with skip.  This needs to be added
   // later.  For now, we read into a temp buffer, then extract what we need.
   double *tmp = new double[(n - 1) * skip + 1];
-  int rc = _dmcObject->readObject(field, tmp, start + s, start + s + (n - 1) * skip);
-  //kdDebug() << "readObject rc=" << rc << " from=" << start+s << " to=" << start + s + (n - 1) * skip << endl;
+  int rc = _dmcObject->readObject(field, tmp, rng.firstIndex + s, rng.firstIndex + s + (n - 1) * skip);
   int i = 0;
+
+#ifdef PIOLIBDEBUG
+  kdDebug() << "readObject rc=" << rc << " from=" << start+s << " to=" << start + s + (n - 1) * skip << endl;
+#endif
+
   while (i < n && i*skip < rc) {
     v[i] = tmp[i * skip];
     ++i;
@@ -207,27 +238,32 @@ bool DMCSource::isValidField(const QString& field) const {
 
 int DMCSource::samplesPerFrame(const QString &field) {
   Q_UNUSED(field)
+
   return 1;
 }
 
 
-int DMCSource::frameCount(const QString& field) const {
-  if (!_valid) {
-    return 0;
-  }
+KstFrameSize DMCSource::frameCountLarge(const QString& field) const {
+  PIOLONG maxLen = 0;
 
-  if (field.isEmpty() || field.lower() == "index" || !_fieldList.contains(field)) {
-    int maxLen = 0;
-    for (QStringList::ConstIterator i = _fieldList.begin(); i != _fieldList.end(); ++i) {
-      assert(!(*i).isEmpty());
-      QSize sz = _dmcObject->range(*i);
-      maxLen = QMAX(sz.height() - sz.width() + 1, maxLen);
+  if (_valid) {
+    if (field.isEmpty() || field.lower() == "index" || !_fieldList.contains(field)) {
+      for (QStringList::ConstIterator i = _fieldList.begin(); i != _fieldList.end(); ++i) {
+        assert(!(*i).isEmpty());
+        DMCRange rng = _dmcObject->range(*i);
+
+        if (rng.lastIndex - rng.firstIndex + 1 > maxLen) {
+          maxLen = rng.lastIndex - rng.firstIndex + 1;
+        }
+      }
+    } else {
+      DMCRange rng = _dmcObject->range(field);
+
+      maxLen = rng.lastIndex - rng.firstIndex + 1;
     }
-    return maxLen;
   }
 
-  QSize sz = _dmcObject->range(field);
-  return sz.height() - sz.width() + 1;
+  return maxLen;
 }
 
 
@@ -247,8 +283,9 @@ bool DMCSource::isEmpty() const {
   }
 
   for (QStringList::ConstIterator i = _fieldList.begin(); i != _fieldList.end(); ++i) {
-    QSize sz = _dmcObject->range(*i);
-    if (sz.height() - sz.width() + 1 > 0) {
+    DMCRange rng = _dmcObject->range(*i);
+
+    if (rng.lastIndex - rng.firstIndex + 1 > 0) {
       return false;
     }
   }
@@ -263,7 +300,7 @@ bool DMCSource::supportsTimeConversions() const {
 }
 
 
-int DMCSource::sampleForTime(const KST::ExtDateTime& time, bool *ok) {
+KstFrameSize DMCSource::sampleForTimeLarge(const KST::ExtDateTime& time, bool *ok) {
   if (!_valid) {
     if (ok) {
       *ok = false;
@@ -271,16 +308,24 @@ int DMCSource::sampleForTime(const KST::ExtDateTime& time, bool *ok) {
     return -1;
   }
 
-  int tai = time.toTime_t() + 86400 * (365 * 12 + 3);
+  double tai = (double)time.toTime_t() + (double)( 86400 * (365 * 12 + 3) );
+
+  //
+  // convert from sec to ms...
+  //
+
+  tai *= 1000.0;
+
   return _dmcObject->sampleForTime(tai, ok);
 }
 
 
-int DMCSource::sampleForTime(double ms, bool *ok) {
+KstFrameSize DMCSource::sampleForTimeLarge(double ms, bool *ok) {
   if (!_valid) {
     if (ok) {
       *ok = false;
     }
+
     return -1;
   }
 
@@ -288,42 +333,54 @@ int DMCSource::sampleForTime(double ms, bool *ok) {
 }
 
 
-KST::ExtDateTime DMCSource::timeForSample(int sample, bool *ok) {
+KST::ExtDateTime DMCSource::timeForSampleLarge(KstFrameSize sample, bool *ok) {
   if (!_valid) {
     if (ok) {
       *ok = false;
     }
+
     return KST::ExtDateTime();
   }
 
   double t = _dmcObject->timeForSample(sample);
+
   if (t != t) {
     if (ok) {
       *ok = false;
     }
+
     return KST::ExtDateTime();
   }
 
   KST::ExtDateTime dt;
-  dt.setTime_t(int(floor(t + 0.5)) - (86400 * (365 * 12 + 3)));
+
+  //
+  // convert to int as the final step to prevent possible overflow conditions...
+  //
+
+  dt.setTime_t( (int)floor( t - (double)(86400 * (365 * 12 + 3)) + 0.5 ) );
+
   return dt;
 }
 
 
-double DMCSource::relativeTimeForSample(int sample, bool *ok) {
+double DMCSource::relativeTimeForSampleLarge(KstFrameSize sample, bool *ok) {
   if (!_valid) {
     if (ok) {
       *ok = false;
     }
+
     return -1;
   }
 
   double i = _dmcObject->timeForSample(0);
   double t = _dmcObject->timeForSample(sample);
+
   if (t != t || i != i) {
     if (ok) {
       *ok = false;
     }
+
     return -1;
   }
 
@@ -335,26 +392,35 @@ double DMCSource::relativeTimeForSample(int sample, bool *ok) {
 extern "C" {
 KstDataSource *create_dmc(KConfig *cfg, const QString& filename, const QString& type) {
   Q_UNUSED(type)
+
   return new DMCSource(cfg, filename);
 }
 
 QStringList provides_dmc() {
   QStringList rc;
+
   rc += "PLANCK DMC I/O";
+
   return rc;
 }
 
 bool supportsTime_dmc(KConfig*, const QString& filename) {
   KstSharedPtr<DMC::Object> pobj = new DMC::Object;
+
   if (!pobj->setGroup(filename) || !pobj->isValid()) {
     return false;
   }
+
   return pobj->fields().contains("TIMES_OF_SAMPLES") || pobj->fields().contains("TIMESEC");
 }
 
 int understands_dmc(KConfig*, const QString& filename) {
   bool rc = DMC::validDatabase(filename);
+
+#ifdef PIOLIBDEBUG
   kdDebug() << "-> Valid dmc database? " << rc << endl;
+#endif
+
   return rc ? 100 : 0;
 }
 
@@ -378,6 +444,7 @@ QStringList fieldList_dmc(KConfig*, const QString& filename, const QString& type
 
   QStringList rc = pobj->fields();
   rc.prepend("INDEX");
+
   return rc;
 }
 
