@@ -18,6 +18,10 @@
 #ifndef _KST_DMC_H
 #define _KST_DMC_H
 
+#include <qsize.h>
+#include <qstring.h>
+#include <qstringlist.h>
+
 #include <config.h>
 
 #include <kstsharedptr.h>
@@ -26,9 +30,10 @@ extern "C" {
 #include <HL2_DMC/PIODB.h>
 }
 
-#include <qsize.h>
-#include <qstring.h>
-#include <qstringlist.h>
+struct DMCRange {
+  PIOLONG firstIndex;
+  PIOLONG lastIndex;
+};
 
 namespace DMC {
     extern bool haveDMC();
@@ -40,18 +45,12 @@ class Source : public KstShared {
     virtual ~Source();
 
     virtual bool isValid() const;
-    
     virtual bool updated() const;
-
     virtual bool setGroup(const QString& group);
-    
     virtual QStringList fields() const;
-
     virtual void reset();
-
-    virtual int readObject(const QString& object, double *buf, long start, long end);
-
-    virtual QSize range(const QString& object) const;
+    virtual PIOLONG readObject(const QString& object, double *buf, PIOLONG start, PIOLONG end);
+    virtual DMCRange range(const QString& object) const;
 
   protected:
     bool _isValid;
