@@ -18,10 +18,9 @@
 #ifndef _KST_DMCOBJ_H
 #define _KST_DMCOBJ_H
 
-
-#include "dmcdata.h"
 #include <qmap.h>
 
+#include "dmcdata.h"
 
 namespace DMC {
     enum TimeType { Undetermined = -1, Unknown = 0, TimeSec = 1, TimesOfSamples = 2 };
@@ -34,24 +33,18 @@ class Object : public Source {
     virtual ~Object();
 
     virtual bool setGroup(const QString& group);
- 
     virtual QStringList fields() const;
-
     virtual void reset();
-
     virtual bool updated() const;
-
-    virtual int readObject(const QString& object, double *buf, long start, long end);
-
-    // FIXME: QSize is a bogus class to use here
-    virtual QSize range(const QString& object) const;
+    virtual PIOLONG readObject(const QString& object, double *buf, PIOLONG start, PIOLONG end);
+    virtual DMCRange range(const QString& object) const;
 
     TimeType typeOfTime();
     double fetchTimePoint(PIOLONG);
 
-    int sampleForTime(double ms, bool *ok);
-    int sampleForTimeRelative(double ms, bool *ok);
-    double timeForSample(int sample);
+    PIOLONG sampleForTime(double ms, bool *ok);
+    PIOLONG sampleForTimeRelative(double ms, bool *ok);
+    double timeForSample(PIOLONG sample);
 
   private:
     // We lazy load the groups, hence mutable
