@@ -43,17 +43,17 @@
 HealpixSource::HealpixSource(KConfig *cfg, const QString& filename, const QString& type, const QDomElement& e) : KstDataSource(cfg, filename, type) {
   int ret;
   size_t poff;
-   
+
   _valid = false;
   if (type.isEmpty( ) || type == "HEALPIX") {
     strncpy(_healpixfile, filename.latin1(), HEALPIX_STRNL);
-    
+
     _names = healpix_strarr_alloc(HEALPIX_FITS_MAXCOL);
     _units = healpix_strarr_alloc(HEALPIX_FITS_MAXCOL);
     _keys = healpix_keys_alloc();
-    
+
     ret = healpix_fits_map_info(_healpixfile, &_mapNside, &_mapOrder, &_mapCoord, &_mapType, &_nMaps, _creator, _extname, _names, _units, _keys);
-    
+
     if (_mapType == HEALPIX_FITS_CUT) {
       poff = 1;
     } else {
@@ -79,7 +79,7 @@ HealpixSource::HealpixSource(KConfig *cfg, const QString& filename, const QStrin
       if (!e.isNull()) {
         load(e);
       }
-      
+
       // populate the metadata
       QString metaVal;
       QString metaName;
@@ -89,42 +89,42 @@ HealpixSource::HealpixSource(KConfig *cfg, const QString& filename, const QStrin
       metaVal.sprintf("%lu", (long unsigned int)_mapNside);
       metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
       _metaData.insert(metaName, metaString);
-      
+
       metaName = "NPIX";
       metaVal.sprintf("%lu", (long unsigned int)_mapNpix);
       metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
       _metaData.insert(metaName, metaString);
-      
+
       metaName = "ORDER";
       metaVal.sprintf("%d", _mapOrder);
       metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
       _metaData.insert(metaName, metaString);
-      
+
       metaName = "COORD";
       metaVal.sprintf("%d", _mapCoord);
       metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
       _metaData.insert(metaName, metaString);
-      
+
       metaName = "TYPE";
       metaVal.sprintf("%d", _mapType);
       metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
       _metaData.insert(metaName, metaString);
-      
+
       metaName = "NMAPS";
       metaVal.sprintf("%lu", (long unsigned int)_nMaps);
       metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
       _metaData.insert(metaName, metaString);
-      
+
       metaName = "CREATOR";
       metaVal.sprintf("%s", _creator);
       metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
       _metaData.insert(metaName, metaString);
-      
+
       metaName = "EXTNAME";
       metaVal.sprintf("%s", _extname);
       metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
       _metaData.insert(metaName, metaString);
-      
+
       for (size_t j = 0; j < _keys->nskeys; j++) {
         metaName.sprintf("%s", _keys->skeynames[j]);
         metaVal.sprintf("%s", _keys->skeyvals[j]);
@@ -145,7 +145,7 @@ HealpixSource::HealpixSource(KConfig *cfg, const QString& filename, const QStrin
         metaString = new KstString(KstObjectTag(metaName, tag()), this, metaVal);
         _metaData.insert(metaName, metaString);
       }
-      
+
       // populate the field list
       QString mapName;
       for (size_t i = 0; i < _nMaps; i++) {
@@ -206,7 +206,6 @@ HealpixSource::~HealpixSource() {
 }
 
 bool HealpixSource::reset() {
-  
   return true;
 }
 
@@ -254,7 +253,7 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
     int keyfirst;
     int ischunk;
     long nelem;
-    
+
     if (_fieldList.contains(field)) {
       fieldnum = _fieldList.findIndex(field);
     } else {
@@ -266,12 +265,12 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
     if (n <= 0) {
       return -1;
     }
-    
+
     vecNside = _mapNside;
     for (int i = 0; i < _vecDegrade; i++) {
       vecNside = (size_t)(vecNside/2);
     }
-    
+
     if (_mapType == HEALPIX_FITS_CUT) {
       // cut-sphere files have extra pixel/hits/error columns
       coltheta = _vecTheta + 2;
@@ -282,12 +281,12 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
       colphi = _vecPhi + 1;
       ncol = (int)_nMaps;
     }
-   
+
     // open file and move to second header unit
     if (fits_open_file(&fp, _healpixfile, READONLY, &ret)) {
       return -1;
     }
-    
+
     if (fits_movabs_hdu(fp, 2, &ttype, &ret)) {
       return -1;
     }
@@ -298,17 +297,17 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
       fits_close_file(fp, &ret);
       return -1;
     }
-    
+
     mapdata = (float*)calloc(_mapNpix, sizeof(float));
     hits = (int*)calloc(12*vecNside*vecNside, sizeof(int));
-    
+
     //-----------------------------------------
     // Read in the first component and degrade
     //-----------------------------------------
-    
+
     for (size_t j = 0; j < _mapNpix; j++) {
-      mapdata[j] = HEALPIX_NULL;
-    }    
+      mapdata[j] = (float)HEALPIX_NULL;
+    }
     if (_mapType == HEALPIX_FITS_CUT) {
       datavec = (float*)calloc((size_t) nrows, sizeof(float));
       pixvec = (int*)calloc((size_t) nrows, sizeof(int));
@@ -388,7 +387,7 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
     }
     comptheta = (float*)calloc(12*vecNside*vecNside, sizeof(float));
     for (size_t i = 0; i < 12*vecNside*vecNside; i++) {
-      comptheta[i] = HEALPIX_NULL;
+      comptheta[i] = (float)HEALPIX_NULL;
       hits[i] = 0;
     }
     for (size_t i = 0; i < _mapNpix; i++) {
@@ -408,17 +407,17 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
     }
     for (size_t i = 0; i < 12*vecNside*vecNside; i++) {
       if (!healpix_is_fnull(comptheta[i])) {
-        comptheta[i] = comptheta[i] / (double)hits[i];
+        comptheta[i] = comptheta[i] / (float)hits[i];
       }
     }
-    
+
     //-----------------------------------------
     // Read in the second component and degrade
     //-----------------------------------------
-    
+
     for (size_t j = 0; j < _mapNpix; j++) {
-      mapdata[j] = HEALPIX_NULL;
-    }    
+      mapdata[j] = (float)HEALPIX_NULL;
+    }
     if (_mapType == HEALPIX_FITS_CUT) {
       datavec = (float*)calloc((size_t) nrows, sizeof(float));
       pixvec = (int*)calloc((size_t) nrows, sizeof(int));
@@ -496,10 +495,10 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
       }
       free(datavec);
     }
-    
+
     compphi = (float*)calloc(12*vecNside*vecNside, sizeof(float));
     for (size_t i = 0; i < 12*vecNside*vecNside; i++) {
-      compphi[i] = HEALPIX_NULL;
+      compphi[i] = (float)HEALPIX_NULL;
       hits[i] = 0;
     }
     for (size_t i = 0; i < _mapNpix; i++) {
@@ -519,20 +518,20 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
     }
     for (size_t i = 0; i < 12*vecNside*vecNside; i++) {
       if (!healpix_is_fnull(compphi[i])) {
-        compphi[i] = compphi[i] / (double)hits[i];
+        compphi[i] = compphi[i] / (float)hits[i];
       }
     }
-    
+
     free(hits);
     free(mapdata);
     fits_close_file(fp, &ret);
-    
+
     //----------------------------------------------
     // compute head and tail coordinates in radians
     //----------------------------------------------
-    
+
     // autoscale magnitude if necessary
-    
+
     if (_autoMag) {
       double vecMag = 0.0;
       for (size_t i = 0; i < 12*vecNside*vecNside; i++) {
@@ -542,16 +541,16 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
       }
       _maxMag = vecMag;
     }
-    
+
     // find distance to 4 nearest neighbor pixels and 
     // use the average to compute how "long" the max
     // valued vector should be for a given pixel.
     // This is *expensive*, but we only load vector 
     // fields infrequently, so should be ok.
-    
+
     // only actually compute the component of the 
     // vectorfield that is requested.
-    
+
     double maxang;
     double thetapart;
     double phipart;
@@ -634,7 +633,7 @@ int HealpixSource::readField(double *v, const QString& field, int s, int n) {
         }
       }
     }
-        
+
     return n;
   } else {
     return -1;
@@ -645,7 +644,7 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
   // If the file is _valid, then we already 
   // have all the header information- no need to read it again.
   // We also know that the matrix index is not out-of-range.
-  
+
   if (_valid && isValidMatrix(matrix)) {
     fitsfile *fp;
     int colnum;
@@ -667,7 +666,7 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
     int keyfirst;
     int ischunk;
     long nelem;
-    
+
     if (_matrixList.contains(matrix)) {
       fieldnum = _matrixList.findIndex(matrix);
     } else {
@@ -692,8 +691,8 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
     }
     if (yStart + nyread > _nY) {
       nyread = _nY - yStart;
-    } 
-    
+    }
+
     if (_mapType == HEALPIX_FITS_CUT) {
       // cut-sphere files have extra pixel/hits/error columns
       colnum = fieldnum + 2;
@@ -702,38 +701,38 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
       colnum = fieldnum + 1;
       ncol = (int)_nMaps;
     }
-   
+
     // open file and move to second header unit
     if (fits_open_file(&fp, _healpixfile, READONLY, &ret)) {
       return -1;
     }
-    
+
     if (fits_movabs_hdu(fp, 2, &ttype, &ret)) {
       return -1;
     }
-    
+
     // read the number of rows
     if (fits_read_btblhdr(fp, ncol, &nrows, &tfields, NULL, NULL, NULL, extname, &pcount, &ret)) {
       ret = 0;
       fits_close_file(fp, &ret);
       return -1;
     }
-    
+
     mapdata = (float*)calloc(_mapNpix, sizeof(float));
     //initialize data to HEALPIX_NULL
     for (size_t j = 0; j < _mapNpix; j++) {
-      mapdata[j] = HEALPIX_NULL;
+      mapdata[j] = (float)HEALPIX_NULL;
     }
-    
+
     if (_mapType == HEALPIX_FITS_CUT) {
-      
+
       // For a cut-sphere file, we must read the entire
       // file and then re-map the data onto a full-sphere
       // vector.
-        
+
       datavec = (float*)calloc((size_t) nrows, sizeof(float));
       pixvec = (int*)calloc((size_t) nrows, sizeof(int));
-      
+
       if (fits_read_col(fp, TINT, 1, 1, 1, nrows, &nullval, pixvec, &nnull, &ret)) {
         free(pixvec);
         free(datavec);
@@ -742,7 +741,7 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
         fits_close_file(fp, &ret);
         return -1;
       }
-      
+
       if (fits_read_col(fp, TFLOAT, colnum, 1, 1, nrows, &nullval, datavec, &nnull, &ret)) {
         free(pixvec);
         free(datavec);
@@ -751,7 +750,7 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
         fits_close_file(fp, &ret);
         return -1;
       }
-      
+
       for (long j = 0; j < nrows; j++) {
         if ((pixvec[j] >= 0) && (pixvec[j] < (int)_mapNpix)) {
           mapdata[pixvec[j]] = datavec[j];
@@ -810,25 +809,25 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
       }
       free(datavec);
     }
-    
+
     fits_close_file(fp, &ret);
-    
+
     // set the matrix to NULL
     for (int i = 0; i < nxread*nyread; i++) {
       data->z[i] = NAN;
     }
-    
+
     double theta, phi;
     size_t ppix;
-    
+
     // compute autorange parameters if necessary
-    
+
     if (_autoTheta || _autoPhi) {
       double mapMinTheta = HEALPIX_PI;
       double mapMaxTheta = 0.0;
       double mapMinPhi = 2.0*HEALPIX_PI;
       double mapMaxPhi = 0.0;
-    
+
       for (size_t i = 0; i < _mapNpix; i++) {
         if (!healpix_is_fnull(mapdata[i])) {
           if (_mapOrder == HEALPIX_RING) {
@@ -867,9 +866,9 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
       //kstdDebug() << "HEALPIX autorange is Theta=[" << mapMinTheta << "..." << mapMaxTheta << "] Phi=[" << mapMinPhi << "..." << mapMaxPhi << "]" << endl;
     }
     //kstdDebug() << "HEALPIX using range Theta=[" << _thetaMin << "..." << _thetaMax << "] Phi=[" << _phiMin << "..." << _phiMax << "]" << endl;
-    
+
     // copy sphere data to matrix.
-    
+
     for (int i = xStart; i < nxread; i++) {
       for (int j = yStart; j < nyread; j++) {
         healpix_proj_rev_car(_thetaMin, _thetaMax, _phiMin, _phiMax, (double)_nX, (double)_nY, (double)i, (double)j, &theta, &phi);
@@ -885,9 +884,9 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
         }
       }
     }
-    
+
     free(mapdata);
-    
+
     // FIXME
     // Eventually, we can just always use radians for the
     // matrix range, since actual display units will be
@@ -905,7 +904,7 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
     //} else {
     //  data->xStepSize = ((_phiMax - _phiMin) / (double)_nX;
     //}
-    
+
     double tMin = _thetaMin;
     double tMax = _thetaMax;
     double pMin = _phiMin;
@@ -915,7 +914,7 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
     phi2External(_phiUnits, pMin);
     phi2External(_phiUnits, pMax);
     //kstdDebug() << "HEALPIX exported range Theta=[" << tMin << "..." << tMax << "] Phi=[" << pMin << "..." << pMax << "]" << endl;
-    
+
     switch (_thetaUnits) {
       case HPUNIT_RAD: case HPUNIT_DEG:
         data->yMin = tMax;
@@ -928,7 +927,7 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
       default:
         break;
     }
-    
+
     data->xMin = pMin;
     switch (_phiUnits) {
       case HPUNIT_RAD:
@@ -955,7 +954,7 @@ int HealpixSource::readMatrix(KstMatrixData* data, const QString& matrix, int xS
       default:
         break;
     }
-        
+
     return nxread*nyread;
   } else {
     return -1;
@@ -975,8 +974,8 @@ bool HealpixSource::isValidField(const QString& field) const {
     } else {
       return false;
     }
-  }   
-  
+  }
+
   return _fieldList.contains(field);
 }
 
@@ -993,7 +992,7 @@ bool HealpixSource::isValidMatrix(const QString& field) const {
     } else {
       return false;
     }
-  }   
+  }
 }
 
 int HealpixSource::samplesPerFrame(const QString &field) {
@@ -1035,26 +1034,26 @@ QString HealpixSource::fileType() const {
 
 void HealpixSource::save(QTextStream &ts, const QString& indent) {
   KstDataSource::save(ts, indent);
-  
+
   double confThetaMin = _thetaMin;
   double confThetaMax = _thetaMax;
   double confPhiMin = _phiMin;
   double confPhiMax = _phiMax;
-  
+
   // export the internal range (in radians) to the
   // selected coordinate system
   theta2External(_thetaUnits, confThetaMin);
   theta2External(_thetaUnits, confThetaMax);
   phi2External(_phiUnits, confPhiMin);
   phi2External(_phiUnits, confPhiMax);
-  
+
   // swap theta min/max if coordinate system requires it
   if (confThetaMax < confThetaMin) {
     double temp = confThetaMax;
     confThetaMax = confThetaMin;
     confThetaMin = temp;
   }
-  
+
   ts << indent << "<dim x=\"" << _nX << "\" y=\"" << _nY << "\"/>" << endl;
   ts << indent << "<theta auto=\"" << _autoTheta << "\" units=\"" << _thetaUnits << "\" min=\"" << confThetaMin << "\" max=\"" << confThetaMax << "\"/>" << endl;
   ts << indent << "<phi auto=\"" << _autoPhi << "\" units=\"" << _phiUnits << "\" min=\"" << confPhiMin << "\" max=\"" << confPhiMax << "\"/>" << endl;
@@ -1130,26 +1129,26 @@ void HealpixSource::load(const QDomElement& e) {
     }
     n = n.nextSibling();
   }
-  
+
   // convert the entered range values into radians and 
   // force them to the correct range.
   theta2Internal(_thetaUnits, confThetaMin);
   theta2Internal(_thetaUnits, confThetaMax);
   phi2Internal(_phiUnits, confPhiMin);
   phi2Internal(_phiUnits, confPhiMax);
-  
+
   // swap theta min/max if coordinate system requires it
   if (confThetaMax < confThetaMin) {
     double temp = confThetaMax;
     confThetaMax = confThetaMin;
     confThetaMin = temp;
   }
-  
+
   _thetaMin = confThetaMin;
   _thetaMax = confThetaMax;
   _phiMin = confPhiMin;
   _phiMax = confPhiMax;
-  
+
   /*
   QString str;
   QString indent = "  ";
@@ -1169,7 +1168,7 @@ bool HealpixSource::isEmpty() const {
 }
 
 void HealpixSource::theta2Internal(int units, double& theta) {
-  
+
   switch (units) {
     case HPUNIT_RAD: 
       break;
@@ -1207,9 +1206,9 @@ void HealpixSource::theta2External(int units, double& theta) {
   }
   return;
 }
-    
+
 void HealpixSource::phi2Internal(int units, double& phi) {
-  
+
   switch (units) {
     case HPUNIT_RAD: 
       break;
@@ -1225,12 +1224,12 @@ void HealpixSource::phi2Internal(int units, double& phi) {
   while (phi > 2.0*HEALPIX_PI) {
     phi -= 2.0*HEALPIX_PI;
   }
-  
+
   return;
 }
-    
+
 void HealpixSource::phi2External(int units, double& phi) {
-  
+
   switch (units) {
     case HPUNIT_RAD: 
       break;
@@ -1274,7 +1273,7 @@ void HealpixSource::loadConfig(KConfig *cfg) {
   double confPhiMin;
   double confPhiMax;
   int tempdegrade;
-  
+
   cfg->setGroup("Healpix General");
   cfg->setGroup(fileName());
   _nX = (int)cfg->readNumEntry("Matrix X Dimension", DEFAULT_XDIM);
@@ -1293,30 +1292,30 @@ void HealpixSource::loadConfig(KConfig *cfg) {
   _autoMag = cfg->readBoolEntry("Vector Magnitude Autoscale", true);
   _maxMag = (cfg->readEntry("Vector Max Magnitude", QString::null)).toDouble();
   _vecQU = cfg->readBoolEntry("Vector is QU", false);
-  
+
   // check degrade factor
   checkDegrade(tempdegrade);
   _vecDegrade = tempdegrade;
-  
+
   // convert the entered range values into radians and 
   // force them to the correct range.
   theta2Internal(_thetaUnits, confThetaMin);
   theta2Internal(_thetaUnits, confThetaMax);
   phi2Internal(_phiUnits, confPhiMin);
   phi2Internal(_phiUnits, confPhiMax);
-  
+
   // swap theta min/max if coordinate system requires it
   if (confThetaMax < confThetaMin) {
     double temp = confThetaMax;
     confThetaMax = confThetaMin;
     confThetaMin = temp;
   }
-  
+
   _thetaMin = confThetaMin;
   _thetaMax = confThetaMax;
   _phiMin = confPhiMin;
   _phiMax = confPhiMax;
-  
+
   return;
 }
 
@@ -1325,21 +1324,21 @@ void HealpixSource::saveConfig(KConfig *cfg) {
   double confThetaMax = _thetaMax;
   double confPhiMin = _phiMin;
   double confPhiMax = _phiMax;
-  
+
   // export the internal range (in radians) to the
   // selected coordinate system
   theta2External(_thetaUnits, confThetaMin);
   theta2External(_thetaUnits, confThetaMax);
   phi2External(_phiUnits, confPhiMin);
   phi2External(_phiUnits, confPhiMax);
-  
+
   // swap theta min/max if coordinate system requires it
   if (confThetaMax < confThetaMin) {
     double temp = confThetaMax;
     confThetaMax = confThetaMin;
     confThetaMin = temp;
   }
-  
+
   cfg->setGroup("Healpix General");
   cfg->setGroup(fileName());
   cfg->writeEntry("Matrix X Dimension", _nX);
@@ -1358,7 +1357,7 @@ void HealpixSource::saveConfig(KConfig *cfg) {
   cfg->writeEntry("Vector Magnitude Autoscale", _autoMag);
   cfg->writeEntry("Vector Max Magnitude", _maxMag);
   cfg->writeEntry("Vector is QU", _vecQU);
-  
+
   return;
 }
 
@@ -1417,7 +1416,7 @@ class ConfigWidgetHealpix : public KstDataSourceConfigWidget {
       _hc->vecQU->setChecked(_cfg->readBoolEntry("Vector is QU", false));
       
       bool hasInstance = (_instance != 0L);
-      
+
       if (hasInstance) {
         _hc->vecTheta->insertStringList(_instance->matrixList());
         _hc->vecPhi->insertStringList(_instance->matrixList());
@@ -1479,7 +1478,7 @@ class ConfigWidgetHealpix : public KstDataSourceConfigWidget {
       _cfg->writeEntry("Vector Magnitude Autoscale", _hc->vecMagAuto->isChecked());
       _cfg->writeEntry("Vector Max Magnitude", _hc->vecMag->text());
       _cfg->writeEntry("Vector is QU", _hc->vecQU->isChecked());
-      
+
       // Update the instance from our new settings
       // Load the config and then save it again, in case
       // the datasource adjusted any of the parameters.
@@ -1511,7 +1510,7 @@ QStringList provides_healpix() {
 
 int understands_healpix(KConfig *cfg, const QString& filename) {
   Q_UNUSED(cfg)
-      
+
   int ret;
   char thealpixfile[HEALPIX_STRNL];
   int tOrder;
@@ -1519,10 +1518,10 @@ int understands_healpix(KConfig *cfg, const QString& filename) {
   int tType;
   size_t tNside;
   size_t tMaps;
-   
+
   strncpy(thealpixfile, filename.latin1(), HEALPIX_STRNL);
   ret = healpix_fits_map_test(thealpixfile, &tNside, &tOrder, &tCoord, &tType, &tMaps);
-    
+
   if (ret) {
     // MUST return 100, since LFIIO datasource returns 99
     // for *all* valid FITS files
@@ -1551,18 +1550,18 @@ QStringList matrixList_healpix(KConfig *cfg, const QString& filename, const QStr
   char **units;
   healpix_keys *keys;
   size_t poff;
-   
+
   strncpy(thealpixfile, filename.latin1(), HEALPIX_STRNL);
-  
+
   names = healpix_strarr_alloc(HEALPIX_FITS_MAXCOL);
   units = healpix_strarr_alloc(HEALPIX_FITS_MAXCOL);
   keys = healpix_keys_alloc();
-    
+
   ret = healpix_fits_map_info(thealpixfile, &tNside, &tOrder, &tCoord, &tType, &tMaps, creator, extname, names, units, keys);
-    
+
   QString mapName;
   QStringList matrices;
-  
+
   if (tType == HEALPIX_FITS_CUT) {
     poff = 1;
   } else {
@@ -1607,21 +1606,21 @@ QStringList matrixList_healpix(KConfig *cfg, const QString& filename, const QStr
     healpix_strarr_free(units, HEALPIX_FITS_MAXCOL);
     return QStringList();
   }
-    
+
   if (complete) {
     *complete = true;
   }
-  
+
   if (typeSuggestion) {
     *typeSuggestion = "HEALPIX";
   }
-  
+
   return matrices;  
 }
 
 QStringList fieldList_healpix(KConfig *cfg, const QString& filename, const QString& type, QString *typeSuggestion, bool *complete) {
   Q_UNUSED(cfg)
-      
+
   if (!type.isEmpty() && !provides_healpix().contains(type)) {
     return QStringList();
   }
@@ -1634,10 +1633,10 @@ QStringList fieldList_healpix(KConfig *cfg, const QString& filename, const QStri
   size_t tNside;
   size_t tMaps;
   QStringList fields;
-   
+
   strncpy(thealpixfile, filename.latin1(), HEALPIX_STRNL);
   ret = healpix_fits_map_test(thealpixfile, &tNside, &tOrder, &tCoord, &tType, &tMaps);
-  
+
   if (ret) {
     fields.append("1 - Vector Field Head Theta");
     fields.append("2 - Vector Field Head Phi");
@@ -1646,15 +1645,15 @@ QStringList fieldList_healpix(KConfig *cfg, const QString& filename, const QStri
   } else {
     return QStringList();
   }
-    
+
   if (complete) {
     *complete = true;
   }
-  
+
   if (typeSuggestion) {
     *typeSuggestion = "HEALPIX";
   }
-  
+
   return fields; 
 }
 
