@@ -32,7 +32,7 @@ class NADSource : public KstDataSource {
     KstObject::UpdateType update(int = -1);
 
     int readField(double *v, const QString &field, int s, int n);
-    int readField(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead);
+    int readFieldSkip(double *v, const QString& field, int s, int n, int skip, int *lastFrameRead);
 
     bool isValidField(const QString &field) const;
 
