@@ -101,6 +101,7 @@ PLANCKIDEFSource::PLANCKIDEFSource( KConfig *cfg, const QString& filename, const
 {
   _fields.setAutoDelete( TRUE );
   _isHFI = false;
+  _isSingleFile = true;
 
   if( type.isEmpty( ) || type == "PLANCKIDEF" )
   {
@@ -1365,13 +1366,20 @@ int PLANCKIDEFSource::readFolderFrames( field *fld, double *v, int s, int n )
             sNew = 0;
           }
 
-          nNew = n;
-          if( sNew + nNew > (*it).frames )
+          if( (*it).frameLo - s > 0 )
           {
-            nNew =  (*it).frames - sNew;
+            vNew = v + ( (*it).frameLo - s );
+          }
+          else
+          {
+            vNew = v;
           }
 
-          vNew = v + (*it).frameLo + sNew;
+          nNew = ( v - vNew ) + n;
+          if( sNew + nNew > (*it).frames )
+          {
+            nNew = (*it).frames - sNew;
+          }
 
           if( nNew > 0 )
           {
