@@ -56,7 +56,7 @@
 #define COLUMNS_PER_READOUTCARD 8
 #define COLUMNS_PER_TEXTFORMAT  8
 
-static char* housekeepingFields[] = {
+static const char* housekeepingFields[] = {
     "Status",                 // value  0 of housekeeping block
     "Sequence Number",        // value  1 of housekeeping block
     "Sync Number",            // value  2 of housekeeping block
@@ -107,7 +107,7 @@ static char* housekeepingFields[] = {
     ""                        // value 42 of housekeeping block is currently reserved
 };
 
-static int numHousekeepingFields = sizeof(housekeepingFields)/sizeof(char*);
+static int numHousekeepingFields = sizeof(housekeepingFields)/sizeof(const char*);
 
 class ScubaSource::Config {
   public:
@@ -1883,11 +1883,17 @@ bool ScubaSource::supportsTimeConversions() const {
 
 
 int ScubaSource::sampleForTime(double ms, bool *ok) {
+  Q_UNUSED(ms)
+  Q_UNUSED(ok)
+
   return 0;
 }
 
 
 int ScubaSource::sampleForTime(const KST::ExtDateTime& time, bool *ok) {
+  Q_UNUSED(time)
+  Q_UNUSED(ok)
+
   return 0;
 }
 
