@@ -83,8 +83,15 @@ class KstBindAxis : public QObject, public KstBinding {
     void setOppositeSuppressed(KJS::ExecState *exec, const KJS::Value& value);
     KJS::Value oppositeSuppressed(KJS::ExecState *exec) const;
 
-    /* @property boolean offsetMode
-       @description True if this axis is in base + offset mode.
+    /* @property number offsetMode
+       @description The base + offset mode. Value must be one of:
+                    <ul>
+                    <li>0 - Automatic</li>
+                    <li>1 - On</li>
+                    <li>2 - Off</li>
+                    </ul>
+      For backwards compatibility the value can also be set as a boolean, in which
+      case true corresponds to On and false corresponds to Automatic.
     */
     void setOffsetMode(KJS::ExecState *exec, const KJS::Value& value);
     KJS::Value offsetMode(KJS::ExecState *exec) const;
