@@ -157,16 +157,20 @@ void KstBindAxisTickLabel::setFont(KJS::ExecState *exec, const KJS::Value& value
   if (value.type() != KJS::StringType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->xTickLabel()->setFontName(value.toString(exec).qstring());
-    _d->fullTickLabel()->setFontName(value.toString(exec).qstring());
-  } else {
-    _d->yTickLabel()->setFontName(value.toString(exec).qstring());
-    _d->fullTickLabel()->setFontName(value.toString(exec).qstring());
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->xTickLabel()->setFontName(value.toString(exec).qstring());
+      _d->fullTickLabel()->setFontName(value.toString(exec).qstring());
+    } else {
+      _d->yTickLabel()->setFontName(value.toString(exec).qstring());
+      _d->fullTickLabel()->setFontName(value.toString(exec).qstring());
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -194,16 +198,20 @@ void KstBindAxisTickLabel::setFontSize(KJS::ExecState *exec, const KJS::Value& v
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->xTickLabel()->setFontSize(i);
-    _d->fullTickLabel()->setFontSize(i);
-  } else {
-    _d->yTickLabel()->setFontSize(i);
-    _d->fullTickLabel()->setFontSize(i);
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->xTickLabel()->setFontSize(i);
+      _d->fullTickLabel()->setFontSize(i);
+    } else {
+      _d->yTickLabel()->setFontSize(i);
+      _d->fullTickLabel()->setFontSize(i);
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -228,14 +236,18 @@ void KstBindAxisTickLabel::setRotation(KJS::ExecState *exec, const KJS::Value& v
   if (value.type() != KJS::NumberType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d);
-  if (_xAxis) {
-    _d->xTickLabel()->setRotation(value.toNumber(exec));
-  } else {
-    _d->yTickLabel()->setRotation(value.toNumber(exec));
+
+  {
+    KstWriteLocker wl(_d);
+    if (_xAxis) {
+      _d->xTickLabel()->setRotation(value.toNumber(exec));
+    } else {
+      _d->yTickLabel()->setRotation(value.toNumber(exec));
+    }
+    _d->setDirty();
   }
-  _d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+
+  KstApp::inst()->paintAllFromScript();
 }
 
 
