@@ -203,9 +203,11 @@ void KstBindBorderedViewObject::setPadding(KJS::ExecState *exec, const KJS::Valu
   }
   KstBorderedViewObjectPtr d = makeBorderedViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setPadding(padding);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setPadding(padding);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -229,9 +231,11 @@ void KstBindBorderedViewObject::setMargin(KJS::ExecState *exec, const KJS::Value
   }
   KstBorderedViewObjectPtr d = makeBorderedViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setMargin(margin);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setMargin(margin);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -255,9 +259,11 @@ void KstBindBorderedViewObject::setBorderWidth(KJS::ExecState *exec, const KJS::
   }
   KstBorderedViewObjectPtr d = makeBorderedViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setBorderWidth(borderWidth);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setBorderWidth(borderWidth);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -281,9 +287,11 @@ void KstBindBorderedViewObject::setBorderColor(KJS::ExecState *exec, const KJS::
   }
   KstBorderedViewObjectPtr d = makeBorderedViewObject(_d);
   if (d) {
-    KstWriteLocker rl(d);
-    d->setBorderColor(cv.toColor());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setBorderColor(cv.toColor());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
