@@ -298,6 +298,40 @@ void KstBindCSD::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 
 #define makeCSD(X) dynamic_cast<KstCSD*>(const_cast<KstObject*>(X.data()))
 
+void KstBindCSD::setVector(KJS::ExecState *exec, const KJS::Value& value) {
+  KstCSDPtr d = makeCSD(_d);
+  if (!d) {
+    createInternalError(exec);
+  }
+
+  KstVectorPtr v = extractVector(exec, value);
+  if (v) {
+    KstWriteLocker wl(d);
+    d->setVector(v);
+    d->setDirty();
+    d->setRecursed(false);
+    if (d->recursion()) {
+      d->setRecursed(true);
+
+      createGeneralError(exec, i18n("Command resulted in a recursion."));
+    }
+  }
+}
+
+
+KJS::Value KstBindCSD::vector(KJS::ExecState *exec) const {
+  KstCSDPtr d = makeCSD(_d);
+  if (d) {
+    KstReadLocker rl(d);
+    KstVectorPtr vp = d->vector();
+    if (vp) {
+      return KJS::Object(new KstBindVector(exec, vp));
+    }
+  }
+  return KJS::Null();
+}
+
+
 void KstBindCSD::setVUnits(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
     return createPropertyTypeError(exec);
