@@ -126,16 +126,12 @@ KJS::Value KstBindDocument::get(KJS::ExecState *exec, const KJS::Identifier& pro
 KJS::Value KstBindDocument::call(KJS::ExecState *exec, KJS::Object& self, const KJS::List& args) {
   int id = this->id();
   if (id <= 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   KstBindDocument *imp = dynamic_cast<KstBindDocument*>(self.imp());
   if (!imp) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::GeneralError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createInternalError(exec);
   }
 
   return (imp->*documentBindings[id - 1].method)(exec, args);
@@ -152,9 +148,7 @@ void KstBindDocument::addBindings(KJS::ExecState *exec, KJS::Object& obj) {
 
 void KstBindDocument::setName(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstApp::inst()->document()->setTitle(value.toString(exec).qstring());
 }
@@ -183,9 +177,7 @@ KJS::Value KstBindDocument::modified(KJS::ExecState *exec) const {
 
 void KstBindDocument::setModified(KJS::ExecState *exec, const KJS::Value& value) {
   if (value.type() != KJS::BooleanType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return;
+    return createPropertyTypeError(exec);
   }
   KstApp::inst()->document()->setModified(value.toBoolean(exec));
 }
@@ -193,9 +185,7 @@ void KstBindDocument::setModified(KJS::ExecState *exec, const KJS::Value& value)
 
 KJS::Value KstBindDocument::newDocument(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 0) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Undefined();
+    return createSyntaxError(exec);
   }
 
   return KJS::Boolean(KstApp::inst()->document()->newDocument());
@@ -204,15 +194,11 @@ KJS::Value KstBindDocument::newDocument(KJS::ExecState *exec, const KJS::List& a
 
 KJS::Value KstBindDocument::load(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() != 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Boolean(false);
+    return createSyntaxError(exec);
   }
 
   if (args[0].type() != KJS::StringType) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-    exec->setException(eobj);
-    return KJS::Boolean(false);
+    return createTypeError(exec, 0);
   }
 
   KURL u;
@@ -229,18 +215,14 @@ KJS::Value KstBindDocument::load(KJS::ExecState *exec, const KJS::List& args) {
 
 KJS::Value KstBindDocument::save(KJS::ExecState *exec, const KJS::List& args) {
   if (args.size() > 1) {
-    KJS::Object eobj = KJS::Error::create(exec, KJS::SyntaxError);
-    exec->setException(eobj);
-    return KJS::Boolean(false);
+    return createSyntaxError(exec);
   }
 
   KstApp *app = KstApp::inst();
 
   if (args.size() == 1) {
     if (args[0].type() != KJS::StringType) {
-      KJS::Object eobj = KJS::Error::create(exec, KJS::TypeError);
-      exec->setException(eobj);
-      return KJS::Boolean(false);
+      return createTypeError(exec, 0);
     }
     app->slotUpdateStatusMsg(i18n("Saving file..."));
     bool rc = app->document()->saveDocument(args[0].toString(exec).qstring(), false, false);
