@@ -74,7 +74,7 @@ KJS::Object KstBindGroup::construct(KJS::ExecState *exec, const KJS::List& args)
 
   KstPlotGroupPtr b = new KstPlotGroup;
   view->appendChild(b.data());
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
   return KJS::Object(new KstBindGroup(exec, b));
 }
 
@@ -227,24 +227,26 @@ KJS::Value KstBindGroup::append(KJS::ExecState *exec, const KJS::List& args) {
   if (d) {
     if (d->tagName() != view->tagName()) {
       if( d->parent() == view->parent()) {
-        KstWriteLocker wl(d);
-        QRect geom;
+        {
+          KstWriteLocker wl(d);
+          QRect geom;
 
-        if (d->children().count() > 0) {
-          geom = d->geometry();
-          geom |= view->geometry();
-        } else {
-          geom = view->geometry();
+          if (d->children().count() > 0) {
+            geom = d->geometry();
+            geom |= view->geometry();
+          } else {
+            geom = view->geometry();
+          }
+
+          view->setSelected(false);
+          view->setFocus(false);
+          view->detach();
+
+          d->modifyGeometry(geom);
+          d->appendChild(view);
         }
 
-        view->setSelected(false);
-        view->setFocus(false);
-        view->detach();
-
-        d->modifyGeometry(geom);
-        d->appendChild(view);
-
-        KstApp::inst()->paintAll(KstPainter::P_PAINT);
+        KstApp::inst()->paintAllFromScript();
       } else {
         return createGeneralError(exec, i18n("Object to be added to group must be at the same level as the group"));
       }
@@ -275,24 +277,26 @@ KJS::Value KstBindGroup::prepend(KJS::ExecState *exec, const KJS::List& args) {
   if (d) {
     if (d->tagName() != view->tagName()) {
       if( d->parent() == view->parent()) {
-        KstWriteLocker wl(d);
-        QRect geom;
+        {
+          KstWriteLocker wl(d);
+          QRect geom;
 
-        if (d->children().count() > 0) {
-          geom = d->geometry();
-          geom |= view->geometry();
-        } else {
-          geom = view->geometry();
+          if (d->children().count() > 0) {
+            geom = d->geometry();
+            geom |= view->geometry();
+          } else {
+            geom = view->geometry();
+          }
+
+          view->setSelected(false);
+          view->setFocus(false);
+          view->detach();
+
+          d->modifyGeometry(geom);
+          d->prependChild(view);
         }
 
-        view->setSelected(false);
-        view->setFocus(false);
-        view->detach();
-
-        d->modifyGeometry(geom);
-        d->prependChild(view);
-
-        KstApp::inst()->paintAll(KstPainter::P_PAINT);
+        KstApp::inst()->paintAllFromScript();
       } else {
         return createGeneralError(exec, i18n("Object to be added to group must be at the same level as the group"));
       }
@@ -321,12 +325,14 @@ KJS::Value KstBindGroup::ungroup(KJS::ExecState *exec, const KJS::List& args) {
 
     if (vo) {
       if (parent) {
-        KstWriteLocker wl(d);
+        {
+          KstWriteLocker wl(d);
 
-        d->flatten();
-        parent->appendChild(vo);
+          d->flatten();
+          parent->appendChild(vo);
+        }
 
-        KstApp::inst()->paintAll(KstPainter::P_PAINT);
+        KstApp::inst()->paintAllFromScript();
       }
     }
   }
