@@ -83,7 +83,7 @@ KJS::Object KstBindLabel::construct(KJS::ExecState *exec, const KJS::List& args)
 
   KstViewLabelPtr b = new KstViewLabel(txt);
   view->appendChild(b.data());
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
   return KJS::Object(new KstBindLabel(exec, b));
 }
 
@@ -230,9 +230,11 @@ void KstBindLabel::setText(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewLabelPtr d = makeLabel(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setText(value.toString(exec).qstring());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setText(value.toString(exec).qstring());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -254,9 +256,11 @@ void KstBindLabel::setFont(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewLabelPtr d = makeLabel(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setFontName(value.toString(exec).qstring());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setFontName(value.toString(exec).qstring());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -279,9 +283,11 @@ void KstBindLabel::setFontSize(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewLabelPtr d = makeLabel(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setFontSize(i);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setFontSize(i);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -303,9 +309,11 @@ void KstBindLabel::setRotation(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewLabelPtr d = makeLabel(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setRotation(value.toNumber(exec));
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setRotation(value.toNumber(exec));
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -328,9 +336,11 @@ void KstBindLabel::setDataPrecision(KJS::ExecState *exec, const KJS::Value& valu
   }
   KstViewLabelPtr d = makeLabel(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setDataPrecision(i);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setDataPrecision(i);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -352,9 +362,11 @@ void KstBindLabel::setInterpreted(KJS::ExecState *exec, const KJS::Value& value)
   }
   KstViewLabelPtr d = makeLabel(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setInterpreted(value.toBoolean(exec));
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setInterpreted(value.toBoolean(exec));
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -376,9 +388,11 @@ void KstBindLabel::setScalarReplacement(KJS::ExecState *exec, const KJS::Value&
   }
   KstViewLabelPtr d = makeLabel(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setDoScalarReplacement(value.toBoolean(exec));
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setDoScalarReplacement(value.toBoolean(exec));
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -416,10 +430,7 @@ KJS::Value KstBindLabel::adjustSizeForText(KJS::ExecState *exec, const KJS::List
     return createSyntaxError(exec);
   }
 
-  KstWriteLocker rl(d);
-  //d->adjustSizeForText();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
-  return KJS::Value();
+  return createGeneralError(exec, i18n("adjustSizeForText is obsolete."));
 }
 
 
