@@ -259,18 +259,18 @@ KJS::Value KstBindObjectCollection::extract(KJS::ExecState *exec, unsigned item)
           type = _plugin->plugin()->data()._outputs[item]._type;
 
           if (type == Plugin::Data::IOValue::TableType) {
-            vector = _plugin->inputVectors()[_plugin->plugin()->data()._outputs[item]._name];
+            vector = _plugin->outputVectors()[_plugin->plugin()->data()._outputs[item]._name];
             if (vector) {
               return KJS::Object(new KstBindVector(exec, vector));
             }
           } else if (type == Plugin::Data::IOValue::StringType) {
-            string = _plugin->inputStrings()[_plugin->plugin()->data()._outputs[item]._name];
+            string = _plugin->outputStrings()[_plugin->plugin()->data()._outputs[item]._name];
             if (string) {
               return KJS::Object(new KstBindString(exec, string));
             }
           } else if (type == Plugin::Data::IOValue::FloatType ||
                      type == Plugin::Data::IOValue::PidType) {
-            scalar = _plugin->inputScalars()[_plugin->plugin()->data()._outputs[item]._name];
+            scalar = _plugin->outputScalars()[_plugin->plugin()->data()._outputs[item]._name];
             if (scalar) {
               return KJS::Object(new KstBindScalar(exec, scalar));
             }
