@@ -76,6 +76,14 @@ class KstBindPlotLabel : public QObject, public KstBinding {
     void setJustification(KJS::ExecState *exec, const KJS::Value& value);
     KJS::Value justification(KJS::ExecState *exec) const;
 
+    /* @property number dataPrecision
+       @description Contains the number of digits of precision to display data
+                    values in the label.  Restricted to a value between 0 and
+                    16 inclusive.
+    */
+    void setDataPrecision(KJS::ExecState *exec, const KJS::Value& value);
+    KJS::Value dataPrecision(KJS::ExecState *exec) const;
+
   protected:
     KstBindPlotLabel(int id);
     void addBindings(KJS::ExecState *exec, KJS::Object& obj);
