@@ -174,19 +174,21 @@ void KstBindTimeInterpretation::setActive(KJS::ExecState *exec, const KJS::Value
   if (value.type() != KJS::BooleanType) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d->_d);
-  bool isIt;
-  KstAxisInterpretation interp;
-  KstAxisDisplay disp;
-  if (_d->_xAxis) {
-    _d->_d->getXAxisInterpretation(isIt, interp, disp);
-    _d->_d->setXAxisInterpretation(value.toBoolean(exec), interp, disp);
-  } else {
-    _d->_d->getYAxisInterpretation(isIt, interp, disp);
-    _d->_d->setYAxisInterpretation(value.toBoolean(exec), interp, disp);
+  {
+    KstWriteLocker wl(_d->_d);
+    bool isIt;
+    KstAxisInterpretation interp;
+    KstAxisDisplay disp;
+    if (_d->_xAxis) {
+      _d->_d->getXAxisInterpretation(isIt, interp, disp);
+      _d->_d->setXAxisInterpretation(value.toBoolean(exec), interp, disp);
+    } else {
+      _d->_d->getYAxisInterpretation(isIt, interp, disp);
+      _d->_d->setYAxisInterpretation(value.toBoolean(exec), interp, disp);
+    }
+    _d->_d->setDirty();
   }
-  _d->_d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -244,47 +246,50 @@ void KstBindTimeInterpretation::setInput(KJS::ExecState *exec, const KJS::Value&
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d->_d);
-  bool isIt;
-  KstAxisInterpretation interp, newInterp;
-  KstAxisDisplay disp;
-  switch (i) {
-    default:
-    case 0:
-      newInterp = AXIS_INTERP_CTIME;
-      break;
-    case 1:
-      newInterp = AXIS_INTERP_AIT;
-      break;
-    case 2:
-      newInterp = AXIS_INTERP_JD;
-      break;
-    case 3:
-      newInterp = AXIS_INTERP_MJD;
-      break;
-    case 4:
-      newInterp = AXIS_INTERP_RJD;
-      break;
-    case 5:
-      newInterp = AXIS_INTERP_YEAR;
-      break;
-    case 6:
-      newInterp = AXIS_INTERP_AIT_NANO;
-      break;
-    case 7:
-      newInterp = AXIS_INTERP_AIT_PLANCK_IDEF;
-      break;
-  }
 
-  if (_d->_xAxis) {
-    _d->_d->getXAxisInterpretation(isIt, interp, disp);
-    _d->_d->setXAxisInterpretation(isIt, newInterp, disp);
-  } else {
-    _d->_d->getYAxisInterpretation(isIt, interp, disp);
-    _d->_d->setYAxisInterpretation(isIt, newInterp, disp);
+  {
+    KstWriteLocker wl(_d->_d);
+    bool isIt;
+    KstAxisInterpretation interp, newInterp;
+    KstAxisDisplay disp;
+    switch (i) {
+      default:
+      case 0:
+        newInterp = AXIS_INTERP_CTIME;
+        break;
+      case 1:
+        newInterp = AXIS_INTERP_AIT;
+        break;
+      case 2:
+        newInterp = AXIS_INTERP_JD;
+        break;
+      case 3:
+        newInterp = AXIS_INTERP_MJD;
+        break;
+      case 4:
+        newInterp = AXIS_INTERP_RJD;
+        break;
+      case 5:
+        newInterp = AXIS_INTERP_YEAR;
+        break;
+      case 6:
+        newInterp = AXIS_INTERP_AIT_NANO;
+        break;
+      case 7:
+        newInterp = AXIS_INTERP_AIT_PLANCK_IDEF;
+        break;
+    }
+
+    if (_d->_xAxis) {
+      _d->_d->getXAxisInterpretation(isIt, interp, disp);
+      _d->_d->setXAxisInterpretation(isIt, newInterp, disp);
+    } else {
+      _d->_d->getYAxisInterpretation(isIt, interp, disp);
+      _d->_d->setYAxisInterpretation(isIt, newInterp, disp);
+    }
+    _d->_d->setDirty();
   }
-  _d->_d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
 }
 
 
@@ -342,45 +347,48 @@ void KstBindTimeInterpretation::setOutput(KJS::ExecState *exec, const KJS::Value
   if (value.type() != KJS::NumberType || !value.toUInt32(i)) {
     return createPropertyTypeError(exec);
   }
-  KstWriteLocker wl(_d->_d);
-  bool isIt;
-  KstAxisInterpretation interp;
-  KstAxisDisplay disp, newDisp;
-  switch (i) {
-    default:
-    case 0:
-      newDisp = AXIS_DISPLAY_DDMMYYHHMMSS_SS;
-      break;
-    case 1:
-      newDisp = AXIS_DISPLAY_YYMMDDHHMMSS_SS;
-      break;
-    case 2:
-      newDisp = AXIS_DISPLAY_JD;
-      break;
-    case 3:
-      newDisp = AXIS_DISPLAY_MJD;
-      break;
-    case 4:
-      newDisp = AXIS_DISPLAY_RJD;
-      break;
-    case 5:
-      newDisp = AXIS_DISPLAY_YEAR;
-      break;
-    case 6:
-      newDisp = AXIS_DISPLAY_KDE_SHORTDATE;
-      break;
-    case 7:
-      newDisp = AXIS_DISPLAY_KDE_LONGDATE;
-      break;
-  }
 
-  if (_d->_xAxis) {
-    _d->_d->getXAxisInterpretation(isIt, interp, disp);
-    _d->_d->setXAxisInterpretation(isIt, interp, newDisp);
-  } else {
-    _d->_d->getYAxisInterpretation(isIt, interp, disp);
-    _d->_d->setYAxisInterpretation(isIt, interp, newDisp);
+  {
+    KstWriteLocker wl(_d->_d);
+    bool isIt;
+    KstAxisInterpretation interp;
+    KstAxisDisplay disp, newDisp;
+    switch (i) {
+      default:
+      case 0:
+        newDisp = AXIS_DISPLAY_DDMMYYHHMMSS_SS;
+        break;
+      case 1:
+        newDisp = AXIS_DISPLAY_YYMMDDHHMMSS_SS;
+        break;
+      case 2:
+        newDisp = AXIS_DISPLAY_JD;
+        break;
+      case 3:
+        newDisp = AXIS_DISPLAY_MJD;
+        break;
+      case 4:
+        newDisp = AXIS_DISPLAY_RJD;
+        break;
+      case 5:
+        newDisp = AXIS_DISPLAY_YEAR;
+        break;
+      case 6:
+        newDisp = AXIS_DISPLAY_KDE_SHORTDATE;
+        break;
+      case 7:
+        newDisp = AXIS_DISPLAY_KDE_LONGDATE;
+        break;
+    }
+
+    if (_d->_xAxis) {
+      _d->_d->getXAxisInterpretation(isIt, interp, disp);
+      _d->_d->setXAxisInterpretation(isIt, interp, newDisp);
+    } else {
+      _d->_d->getYAxisInterpretation(isIt, interp, disp);
+      _d->_d->setYAxisInterpretation(isIt, interp, newDisp);
+    }
+    _d->_d->setDirty();
   }
-  _d->_d->setDirty();
-  KstApp::inst()->paintAll(KstPainter::P_PAINT);
+  KstApp::inst()->paintAllFromScript();
 }
