@@ -209,9 +209,11 @@ void KstBindViewObject::setColor(KJS::ExecState *exec, const KJS::Value& value)
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker rl(d);
-    d->setForegroundColor(cv.toColor());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setForegroundColor(cv.toColor());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -233,9 +235,11 @@ void KstBindViewObject::setBackgroundColor(KJS::ExecState *exec, const KJS::Valu
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker rl(d);
-    d->setBackgroundColor(cv.toColor());
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setBackgroundColor(cv.toColor());
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -256,17 +260,19 @@ void KstBindViewObject::setMaximized(KJS::ExecState *exec, const KJS::Value& val
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
+    {
+      KstWriteLocker wl(d);
 
-    bool maximized = value.toBoolean(exec);
-    if (maximized) {
-      KstViewObjectPtr tlv = d->topLevelParent();
-      if (tlv) {
-        tlv->recursively(&KstViewObject::setMaximized, false);
+      bool maximized = value.toBoolean(exec);
+      if (maximized) {
+        KstViewObjectPtr tlv = d->topLevelParent();
+        if (tlv) {
+          tlv->recursively(&KstViewObject::setMaximized, false);
+        }
       }
+      d->setMaximized(value.toBoolean(exec));
     }
-    d->setMaximized(value.toBoolean(exec));
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -289,9 +295,11 @@ void KstBindViewObject::setSize(KJS::ExecState *exec, const KJS::Value& value) {
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->resize(imp->_sz);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->resize(imp->_sz);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -312,9 +320,11 @@ void KstBindViewObject::setTransparent(KJS::ExecState *exec, const KJS::Value& v
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setTransparent(value.toBoolean(exec));
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setTransparent(value.toBoolean(exec));
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -336,9 +346,11 @@ void KstBindViewObject::setOnGrid(KJS::ExecState *exec, const KJS::Value& value)
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setOnGrid(value.toBoolean(exec));
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setOnGrid(value.toBoolean(exec));
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -361,11 +373,13 @@ void KstBindViewObject::setColumns(KJS::ExecState *exec, const KJS::Value& value
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->setOnGrid(true);
-    d->setColumns(cols);
-    d->cleanup(cols);
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->setOnGrid(true);
+      d->setColumns(cols);
+      d->cleanup(cols);
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -388,9 +402,11 @@ void KstBindViewObject::setPosition(KJS::ExecState *exec, const KJS::Value& valu
   }
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker wl(d);
-    d->move(QPoint(int(imp->_x), int(imp->_y)));
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(d);
+      d->move(QPoint(int(imp->_x), int(imp->_y)));
+    }
+    KstApp::inst()->paintAllFromScript();
   }
 }
 
@@ -436,7 +452,7 @@ KJS::Value KstBindViewObject::resize(KJS::ExecState *exec, const KJS::List& args
 
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker rl(d);
+    KstWriteLocker wl(d);
     d->resize(QSize(x, y));
 
     KstViewObjectPtr vo = d->topLevelParent();
@@ -473,7 +489,7 @@ KJS::Value KstBindViewObject::move(KJS::ExecState *exec, const KJS::List& args)
 
   KstViewObjectPtr d = makeViewObject(_d);
   if (d) {
-    KstWriteLocker rl(d);
+    KstWriteLocker wl(d);
     d->move(QPoint(x, y));
 
     KstViewObjectPtr vo = d->topLevelParent();
