@@ -112,11 +112,13 @@ KJS::Value KstBindViewObjectCollection::append(KJS::ExecState *exec, const KJS::
       return createTypeError(exec, 0);
     }
 
-    KstWriteLocker rl(_parent);
-    c->detach();
-    _parent->appendChild(c);
-    _parent->setDirty();
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(_parent);
+      c->detach();
+      _parent->appendChild(c);
+      _parent->setDirty();
+    }
+    KstApp::inst()->paintAllFromScript();
     return KJS::Undefined();
   }
 
@@ -135,11 +137,13 @@ KJS::Value KstBindViewObjectCollection::prepend(KJS::ExecState *exec, const KJS:
       return createTypeError(exec, 0);
     }
 
-    KstWriteLocker rl(_parent);
-    c->detach();
-    _parent->prependChild(c);
-    _parent->setDirty();
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(_parent);
+      c->detach();
+      _parent->prependChild(c);
+      _parent->setDirty();
+    }
+    KstApp::inst()->paintAllFromScript();
     return KJS::Undefined();
   }
 
@@ -153,10 +157,12 @@ KJS::Value KstBindViewObjectCollection::clear(KJS::ExecState *exec, const KJS::L
   }
 
   if (_parent) {
-    KstWriteLocker rl(_parent);
-    _parent->clearChildren();
-    _parent->setDirty();
-    KstApp::inst()->paintAll(KstPainter::P_PAINT);
+    {
+      KstWriteLocker wl(_parent);
+      _parent->clearChildren();
+      _parent->setDirty();
+    }
+    KstApp::inst()->paintAllFromScript();
     return KJS::Undefined();
   }
 
@@ -172,18 +178,22 @@ KJS::Value KstBindViewObjectCollection::remove(KJS::ExecState *exec, const KJS::
   if (_parent) {
     KstViewObjectPtr c = extractViewObject(exec, args[0]);
     if (c) {
-      KstWriteLocker rl(_parent);
-      _parent->removeChild(c);
-      KstApp::inst()->paintAll(KstPainter::P_PAINT);
+      {
+        KstWriteLocker wl(_parent);
+        _parent->removeChild(c);
+      }
+      KstApp::inst()->paintAllFromScript();
     } else {
       unsigned i = 0;
       if (args[0].type() == KJS::NumberType && args[0].toUInt32(i)) {
         if (i >= _parent->children().count()) {
           return createRangeError(exec, 0);
         } else {
-          KstWriteLocker rl(_parent);
-          _parent->removeChild(_parent->children()[i]);
-          KstApp::inst()->paintAll(KstPainter::P_PAINT);
+          {
+            KstWriteLocker wl(_parent);
+            _parent->removeChild(_parent->children()[i]);
+          }
+          KstApp::inst()->paintAllFromScript();
         }
       } else {
         return createTypeError(exec, 0);
