@@ -301,6 +301,18 @@ bool KstJS::addToOutput(const QString &output) {
   return retVal;
 }
 
+
+bool KstJS::autoWriteHistory(const QString &filename, bool append) {
+  bool retVal = false;
+
+  if (_iface) {
+    retVal = _iface->autoWriteHistory(filename, append);
+  }
+
+  return retVal;
+}
+
+
 static char shellStr[30];
 
 void KstJS::showConsole() {
