@@ -50,6 +50,7 @@
 
 static const char description[] = I18N_NOOP("Kst: a data viewing program.");
 static QStringList startupErrors;
+static QStringList startupWarnings;
 
 static KCmdLineOptions options[] = {
   { "y <Y>", I18N_NOOP("Field for Y axis (multiple allowed)"), 0 },
@@ -257,9 +258,10 @@ static void SetEqXRanges(QString xeqS, double *min, double *max, int *n, bool *o
 /*                                                                */
 /******************************************************************/
 static KstRVector *GetOrCreateVector(const QString& field, KstDataSourcePtr file, InType &in) {
-  int i_v = 0, n_v;
-  KstRVector *V;
   KstRVectorList vectorList = kstObjectSubList<KstVector,KstRVector>(KST::vectorList);
+  KstRVector *V;
+  int i_v = 0;
+  int n_v;
 
   n_v = vectorList.count();
 
@@ -272,8 +274,12 @@ static KstRVector *GetOrCreateVector(const QString& field, KstDataSourcePtr file
 
   V = new KstRVector(file, field, KstObjectTag(KST::suggestVectorName(field), file->tag(), false), in.f, in.n, in.skip, in.doskip, in.doave);
   if (!V->isValid()) {
-    if (file->fileType() == "stdin") {
-      startupErrors.append(i18n("Failed to create vector '%1' from file '%2'.  Trying again later.").arg(field).arg(file->fileName()));
+    //
+    // use rawFileType() here as fileType() will return ASCII in the case that we
+    //  are using stdin, so isn't fit for purpose...
+    //
+    if (file->rawFileType() == "stdin") {
+      startupWarnings.append(i18n("Failed to create vector '%1' from file '%2'.  Trying again later.").arg(field).arg(file->fileName()));
     } else {
       startupErrors.append(i18n("Failed to create vector '%1' from file '%2'.").arg(field).arg(file->fileName()));
       V = 0L;
@@ -532,8 +538,7 @@ int main(int argc, char *argv[]) {
 
         if (file) {
           if (!file->isValid() || file->isEmpty()) {
-            kstdError() << i18n("No data in file %1.  Trying to continue...").arg(args->arg(i_file)) << endl;
-            // The file might get data later!
+            // the file might get data later!
           }
 
           KST::dataObjectList.lock().writeLock();
@@ -852,6 +857,10 @@ int main(int argc, char *argv[]) {
         KstDebug::self()->log(startupErrors[i], KstDebug::Error);
       }
       startupErrors.clear();
+      for (size_t i = 0; i < startupWarnings.size(); ++i) {
+        KstDebug::self()->log(startupWarnings[i], KstDebug::Warning);
+      }
+      startupWarnings.clear();
     }
 
     // LEAVE THIS HERE - causes crashes otherwise!
