@@ -57,6 +57,10 @@ KST_EXPORT class KstData {
     virtual int vectorToFile(KstVectorPtr v, QFile *f);
     virtual int vectorsToFile(const KstVectorList& l, QFile *f, bool interpolate);
 
+    /** Save a matrix to a file */
+    virtual int matrixToFile(KstMatrixPtr v, QFile *f);
+
+
     /** The list of plots for the given window.  Returns all plots if
         the window is empty/null. */
     virtual QStringList plotList(const QString& window = QString::null);
