@@ -41,18 +41,16 @@ namespace KST {
       Plugin(KService::Ptr svc) : KstShared(), service(svc), _lib(0L) {
         assert(service);
         _plugLib = service->library();
-        //kstdDebug() << "Create plugin " << (void*)this << " " << service->property("Name").toString() << endl;
       }
 
-	protected:
+  protected:
       virtual ~Plugin() {
-        //kstdDebug() << "Destroy plugin " << (void*)this << " " << service->property("Name").toString() << endl;
         if (_lib) {
           _lib->unload();
         }
       }
 
-	public:
+  public:
       Q_UINT32 key() const {
         Q_UINT32 (*sym)() = (Q_UINT32(*)())symbol("key");
         if (sym) {
@@ -122,12 +120,11 @@ namespace KST {
       KstDataSource *create(KConfig *cfg, const QString& filename, const QString& type = QString::null) const {
         KstDataSource *(*sym)(KConfig*, const QString&, const QString&) = (KstDataSource*(*)(KConfig*, const QString&, const QString&))symbol("create");
         if (sym) {
-          //kstdDebug() << "Trying to create " << filename << " type=" << type << " with " << service->property("Name").toString() << endl;
           KstDataSource *ds = (sym)(cfg, filename, type);
           if (ds) {
             ds->_source = service->property("Name").toString();
           }
-          //kstdDebug() << (ds ? "SUCCESS" : "FAILED") << endl;
+
           return ds;
         }
 
@@ -137,12 +134,11 @@ namespace KST {
       KstDataSource *create(KConfig *cfg, const QString& filename, const QString& type, const QDomElement& e) const {
         KstDataSource *(*sym)(KConfig*, const QString&, const QString&, const QDomElement&) = (KstDataSource*(*)(KConfig*, const QString&, const QString&, const QDomElement&))symbol("load");
         if (sym) {
-          //kstdDebug() << "Trying to create " << filename << " type=" << type << " with " << service->property("Name").toString() << endl;
           KstDataSource *ds = (sym)(cfg, filename, type, e);
           if (ds) {
             ds->_source = service->property("Name").toString();
           }
-          //kstdDebug() << (ds ? "SUCCESS" : "FAILED") << endl;
+
           return ds;
         } else {
           KstDataSource *(*sym)(KConfig*, const QString&, const QString&) = (KstDataSource*(*)(KConfig*, const QString&, const QString&))symbol("create");
@@ -151,6 +147,7 @@ namespace KST {
             if (ds) {
               ds->_source = service->property("Name").toString();
             }
+
             return ds;
           }
         }
@@ -205,9 +202,8 @@ namespace KST {
       int understands(KConfig *cfg, const QString& filename) const {
         int (*sym)(KConfig*, const QString&) = (int(*)(KConfig*, const QString&))symbol("understands");
         if (sym) {
-          //kstdDebug() << "Checking if " << service->property("Name").toString() << " understands " << filename << endl;
           int rc = (sym)(cfg, filename);
-          //kstdDebug() << "result: " << rc << endl;
+
           return rc;
         }
 
@@ -227,8 +223,8 @@ namespace KST {
       bool supportsHierarchy() const {
         bool (*sym)() = (bool(*)())symbol("supportsHierarchy");
         if (sym) {
-          //kstdDebug() << "Checking if " << service->property("Name").toString() << " provides " << type << endl;
           bool rc = (sym)();
+
           return rc;
         }
 
@@ -242,7 +238,6 @@ namespace KST {
       QStringList provides() const {
         QStringList (*sym)() = (QStringList(*)())symbol("provides");
         if (sym) {
-          //kstdDebug() << "Checking if " << service->property("Name").toString() << " provides " << type << endl;
           return (sym)();
         }
 
@@ -282,89 +277,5 @@ namespace KST {
       }
   };
 
-#if 0
-  class BasicPlugin : public DataObjectPlugin {
-    public:
-      BasicPlugin(KService::Ptr svc) : DataObjectPlugin(svc) {
-      }
-
-      virtual ~BasicPlugin() {
-      }
-
-      QWidget *configWidget(const QString& name) const {
-        Q_UNUSED(name);
-        return 0L;
-      }
-
-      QStringList inputVectorList() const {
-        QStringList (*sym)() = (QStringList(*)())symbol("inputVectorList");
-        if (sym) {
-          return (sym)();
-        }
-
-        return QStringList();
-      }
-
-      QStringList inputScalarList() const {
-        QStringList (*sym)() = (QStringList(*)())symbol("inputScalarList");
-        if (sym) {
-          return (sym)();
-        }
-
-        return QStringList();
-      }
-
-      QStringList inputStringList() const {
-        QStringList (*sym)() = (QStringList(*)())symbol("inputStringList");
-        if (sym) {
-          return (sym)();
-        }
-
-        return QStringList();
-      }
-
-      QStringList outputVectorList() const {
-        QStringList (*sym)() = (QStringList(*)())symbol("outputVectorList");
-        if (sym) {
-          return (sym)();
-        }
-
-        return QStringList();
-      }
-
-      QStringList outputScalarList() const {
-        QStringList (*sym)() = (QStringList(*)())symbol("outputScalarList");
-        if (sym) {
-          return (sym)();
-        }
-
-        return QStringList();
-      }
-
-      QStringList outputStringList() const {
-        QStringList (*sym)() = (QStringList(*)())symbol("outputStringList");
-        if (sym) {
-          return (sym)();
-        }
-
-        return QStringList();
-      }
-  };
-
-  class CPlugin : public DataObjectPlugin {
-    public:
-      CPlugin(KService::Ptr svc) : DataObjectPlugin(svc) {
-      }
-
-      virtual ~CPlugin() {
-      }
-
-      QWidget *configWidget(const QString& name) const {
-        Q_UNUSED(name);
-        return 0L;
-      }
-  };
-#endif
-
   typedef QValueList<KstSharedPtr<KST::Plugin> > PluginInfoList;
 }
