@@ -691,6 +691,11 @@ QString KstDataSource::fileType() const {
 }
 
 
+QString KstDataSource::rawFileType() const {
+  return fileType();
+}
+
+
 void KstDataSource::save(QTextStream &ts, const QString& indent) {
   QString name = QStyleSheet::escape(_filename);
 
@@ -882,7 +887,7 @@ bool KstDataSource::setConfiguration(QString setting, const QString &value) {
 
 /////////////////////////////////////////////////////////////////////////////
 KstDataSourceConfigWidget::KstDataSourceConfigWidget()
-: QWidget(0L), _cfg(0L) {
+: QWidget(0L), _cfg(0L), _instance(0L) {
 }
 
 
