@@ -441,7 +441,7 @@ void KstObjectCollection<T>::doRename(T *o, const KstObjectTag& newTag) {
 
   _root.removeDescendant(o, &_index);
 
-  o->KstObject::setTagName(newTag);
+  o->KstObject::setTagNameNoSignal(newTag);
 
   if (_root.addDescendant(o, &_index)) {
     if (_updateDisplayTags) {
