@@ -85,6 +85,7 @@
 #include "kstuinames.h"
 #include "kstvectordefaults.h"
 #include "kstvectorsavedialog_i.h"
+#include "kstmatrixsavedialog_i.h"
 #include "kstvectordialog_i.h"
 #include "kstviewmanager_i.h"
 #include "kstviewscalarsdialog_i.h"
@@ -162,6 +163,7 @@ KstApp::KstApp(QWidget *parent, const char *name)
   changeNptsDialog = new KstChangeNptsDialogI(this);
   graphFileDialog = new KstGraphFileDialogI(this);
   vectorSaveDialog = new KstVectorSaveDialogI(this);
+  matrixSaveDialog = new KstMatrixSaveDialogI(this);
   _monochromeDialog = new KstMonochromeDialogI(this);
   _quickStartDialog = new KstQuickStartDialogI(this, 0 , true);
 
@@ -683,6 +685,15 @@ void KstApp::initActions() {
   _vectorSaveAction->setWhatsThis(i18n("Bring up a dialog box\n"
                                        "to save vectors to text files."));
 
+  /************/
+  _matrixSaveAction = new KAction(i18n("Save Matrices to Disk..."),
+                                  0, 0,
+                                  matrixSaveDialog, SLOT(show()),
+                                  actionCollection(),
+                                  "matrixsavedialog_action");
+  _matrixSaveAction->setWhatsThis(i18n("Bring up a dialog box\n"
+                                       "to save matrices to text files."));
+
   /************/
   SamplesDownAction = new KAction(i18n("&Back 1 Screen"),
                                   "player_rew",
@@ -2209,6 +2220,9 @@ void KstApp::updateDialogs(bool onlyVisible) {
     if (!onlyVisible || vectorSaveDialog->isShown()) {
       vectorSaveDialog->init();
     }
+    if (!onlyVisible || matrixSaveDialog->isShown()) {
+      matrixSaveDialog->init();
+    }
     updateDataDialogs(false);
     updateDataManager(onlyVisible);
     updateViewManager(onlyVisible);
@@ -2284,9 +2298,7 @@ void KstApp::showDataWizard() {
   dw->exec();
   if (dw->result() == QDialog::Accepted) {
     delete dw; // leave this here - releases references
-    forceUpdate();
-    doc->setModified();
-    updateDialogs();
+    doc->wasModified();
   } else {
     delete dw;
   }
@@ -2299,9 +2311,7 @@ void KstApp::showDataWizardWithFile(const QString &input) {
   dw->exec();
   if (dw->result() == QDialog::Accepted) {
     delete dw; // leave this here - releases references
-    forceUpdate();
-    doc->setModified();
-    updateDialogs();
+    doc->wasModified();
   } else {
     delete dw;
   }
