@@ -40,6 +40,7 @@
 #include "kstdataobjectcollection.h"
 #include "kstviewwindow.h"
 #include "kstuinames.h"
+#include "scalarselector.h"
 #include "vectorselector.h"
 #include "kstplotlabel.h"
 
@@ -76,6 +77,7 @@ KstCurveDialogI::KstCurveDialogI(QWidget* parent, const char* name, bool modal,
   connect(_w->_curveAppearance->_showLines, SIGNAL(clicked()), this, SLOT(setShowLinesDirty()));
   connect(_w->_curveAppearance->_showBars, SIGNAL(clicked()), this, SLOT(setShowBarsDirty()));
   connect(_w->_checkBoxIgnoreAutoscale, SIGNAL(clicked()), this, SLOT(setCheckBoxIgnoreAutoscaleDirty()));
+  connect(_w->_checkBoxYVectorOffset, SIGNAL(clicked()), this, SLOT(setCheckBoxYVectorOffsetDirty()));
 
   // for apply button
   connect(_w->_xVector, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
@@ -101,6 +103,8 @@ KstCurveDialogI::KstCurveDialogI(QWidget* parent, const char* name, bool modal,
   connect(_w->_checkBoxYMinusSameAsPlus, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
   connect(_w->_curveAppearance, SIGNAL(changed()), this, SLOT(wasModifiedApply()));
   connect(_w->_checkBoxIgnoreAutoscale, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_checkBoxYVectorOffset, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_scalarSelectorYVectorOffset, SIGNAL(selectionChanged(const QString&)), this, SLOT(wasModifiedApply()));
 
   _w->_xError->provideNoneVector(true);
   _w->_yError->provideNoneVector(true);
@@ -187,6 +191,24 @@ void KstCurveDialogI::fillFieldsForEdit() {
       cp->lineStyle(), cp->barStyle(), cp->pointDensity());
 
   _w->_checkBoxIgnoreAutoscale->setChecked(cp->ignoreAutoScale());
+  _w->_checkBoxYVectorOffset->setChecked(cp->yVectorOffset());
+  if (cp->yVectorOffset()) {
+    _w->_scalarSelectorYVectorOffset->setSelection(cp->yVectorOffsetTag().displayString());
+  } else {
+    //
+    // if the user doesn't have the y-offset enabled then we set the scalar giving the mean
+    //  of the y-vector as a reasonable default...
+    //
+    KstVectorPtr yVector = *cp->inputVectors().find("Y");
+    if (yVector) {
+      KstScalarPtr meanScalar;
+
+      meanScalar = yVector->scalars().find("mean");
+      if (meanScalar) {
+        _w->_scalarSelectorYVectorOffset->setSelection(meanScalar->tag().displayString());
+      }
+    }
+  }
 
   cp->unlock();
 
@@ -218,6 +240,7 @@ void KstCurveDialogI::fillFieldsForNew() {
   _w->_curveAppearance->reset();
   _w->_interp->setCurrentItem(0);
   _w->_checkBoxIgnoreAutoscale->setChecked(false);
+  _w->_checkBoxYVectorOffset->setChecked(false);
 
   adjustSize();
   resize(minimumSizeHint());
@@ -233,6 +256,7 @@ void KstCurveDialogI::update() {
   _w->_yError->update();
   _w->_xMinusError->update();
   _w->_yMinusError->update();
+  _w->_scalarSelectorYVectorOffset->update();
 }
 
 
@@ -334,6 +358,7 @@ bool KstCurveDialogI::newObject() {
   curve->setBarStyle(_w->_curveAppearance->barStyle());
   curve->setPointDensity(_w->_curveAppearance->pointDensity());
   curve->setIgnoreAutoScale(_w->_checkBoxIgnoreAutoscale->isChecked());
+  curve->setYVectorOffset(_w->_checkBoxYVectorOffset->isChecked());
 
   curve->setInterp(KstVCurve::InterpType(_w->_interp->currentItem()));
 
@@ -465,6 +490,13 @@ bool KstCurveDialogI::editSingleObject(KstVCurvePtr cvPtr) {
     cvPtr->setIgnoreAutoScale(_w->_checkBoxIgnoreAutoscale->isChecked());
   }
 
+  if (_checkBoxYVectorOffsetDirty) {
+    cvPtr->setYVectorOffset(_w->_checkBoxYVectorOffset->isChecked());
+    if (_scalarSelectorYVectorOffsetDirty) {
+      cvPtr->setYVectorOffsetScalar(_w->_scalarSelectorYVectorOffset->selectedScalarPtr());
+    }
+  }
+
   if (_interpComboDirty) {
     cvPtr->setInterp(KstVCurve::InterpType(_w->_interp->currentItem()));
   }
@@ -495,6 +527,8 @@ bool KstCurveDialogI::editObject() {
     _barStyleDirty = _w->_curveAppearance->_barStyle->currentItem() > 0;
     _interpComboDirty = (_w->_interp->currentItem()<4);
 
+    _scalarSelectorYVectorOffsetDirty = _w->_scalarSelectorYVectorOffset->_scalar->currentItem() != 0;
+
     bool didEdit = false;
 
     for (uint i = 0; i < _editMultipleWidget->_objectList->count(); i++) {
@@ -557,6 +591,9 @@ bool KstCurveDialogI::editObject() {
     _barStyleDirty = true;
     _interpComboDirty = true;
     _checkBoxIgnoreAutoscaleDirty = true;
+    _checkBoxYVectorOffsetDirty = true;
+    _scalarSelectorYVectorOffsetDirty = true;
+
     if (!editSingleObject(cp)) {
       return false;
     }
@@ -583,10 +620,12 @@ void KstCurveDialogI::populateEditMultiple() {
   _w->_xMinusError->_vector->setCurrentItem(0);
   _w->_yMinusError->_vector->insertItem("", 0);
   _w->_yMinusError->_vector->setCurrentItem(0);
+  _w->_scalarSelectorYVectorOffset->_scalar->insertItem("", 0);
+  _w->_scalarSelectorYVectorOffset->_scalar->setCurrentItem(0);
 
   _w->_interp->insertItem("", 4);
   _w->_interp->setCurrentItem(4);
-  
+
   // single blank characters to differentiate between QPixmaps
   _w->_curveAppearance->_combo->insertItem(" ", 0);
   _w->_curveAppearance->_combo->setCurrentItem(0);
@@ -596,7 +635,7 @@ void KstCurveDialogI::populateEditMultiple() {
   _w->_curveAppearance->_comboLineStyle->setCurrentItem(0);
   _w->_curveAppearance->_barStyle->insertItem(" ", 0);
   _w->_curveAppearance->_barStyle->setCurrentItem(0);
-  
+
   _w->_curveAppearance->_spinBoxLineWidth->setMinValue(_w->_curveAppearance->_spinBoxLineWidth->minValue() - 1);
   _w->_curveAppearance->_spinBoxLineWidth->setSpecialValueText(" ");
   _w->_curveAppearance->_spinBoxLineWidth->setValue(_w->_curveAppearance->_spinBoxLineWidth->minValue());
@@ -613,7 +652,9 @@ void KstCurveDialogI::populateEditMultiple() {
   _w->_curveAppearance->_showBars->setNoChange();
   _w->_checkBoxIgnoreAutoscale->setTristate(true);
   _w->_checkBoxIgnoreAutoscale->setNoChange();
-  
+  _w->_checkBoxYVectorOffset->setTristate(true);
+  _w->_checkBoxYVectorOffset->setNoChange();
+
   toggledXErrorSame(false);
   toggledYErrorSame(false);
 
@@ -642,6 +683,8 @@ void KstCurveDialogI::populateEditMultiple() {
   _barStyleDirty = false;
   _checkBoxIgnoreAutoscaleDirty = false;
   _interpComboDirty = false;
+  _checkBoxYVectorOffsetDirty = false;
+  _scalarSelectorYVectorOffsetDirty = false;
 }
 
 
@@ -681,6 +724,12 @@ void KstCurveDialogI::setCheckBoxIgnoreAutoscaleDirty() {
 }
 
 
+void KstCurveDialogI::setCheckBoxYVectorOffsetDirty() {
+  _w->_checkBoxYVectorOffset->setTristate(false);
+  _checkBoxYVectorOffsetDirty = true;
+}
+
+
 void KstCurveDialogI::cleanup() {
   // get rid of the blanks in _curveAppearance
   if (_editMultipleMode) {
