@@ -154,7 +154,6 @@ int KstGuiData::vectorToFile(KstVectorPtr v, QFile *f) {
 
 
 int KstGuiData::vectorsToFile(const KstVectorList& vl, QFile *f, bool interpolate) {
-  KstApp *app = KstApp::inst();
   int maxlen = -1;
 
   if (interpolate) { // code duplication is faster
@@ -175,8 +174,6 @@ int KstGuiData::vectorsToFile(const KstVectorList& vl, QFile *f, bool interpolat
   }
 
   QString saving = i18n("Saving vectors...");
-  register int modval = kMax(maxlen/100, 100);
-  app->slotUpdateProgress(maxlen, 0, QString::null);
 
   bool first = true;
   QString ltxt = ";";
@@ -214,17 +211,39 @@ int KstGuiData::vectorsToFile(const KstVectorList& vl, QFile *f, bool interpolat
     }
     ltxt += "\n";
     f->writeBlock(ltxt.ascii(), ltxt.length());
-    if (line % modval == 0) {
-      app->slotUpdateProgress(maxlen, line, saving);
-    }
   }
 
   for (KstVectorList::ConstIterator v = vl.begin(); v != vl.end(); ++v) {
     (*v)->unlock();
   }
 
-  app->slotUpdateProgress(0, 0, QString::null);
+  return 0;
+}
 
+
+int KstGuiData::matrixToFile(KstMatrixPtr m, QFile *f) {
+  KstApp *app = KstApp::inst();
+#define BSIZE 128
+  char buf[BSIZE];
+
+  m->readLock();
+
+  int xSize = m->xNumSteps();
+  int ySize = m->yNumSteps();
+
+  QString ltxt = QString("[MATRIX,%1,%2,%3,%4,%5]\n").arg(m->yNumSteps()).arg(m->minX()).arg(m->minY()).arg(m->xStepSize()).arg(m->yStepSize());
+  f->writeBlock(ltxt.ascii(), ltxt.length());
+
+  for (int x = 0; x < xSize; x++) {
+    for (int y = 0; y < ySize; y++) {
+      int l = snprintf(buf, BSIZE, "%.15g\n", m->valueRaw(x,y));
+      f->writeBlock(buf, l);
+    }
+  }
+
+  m->unlock();
+
+#undef BSIZE
   return 0;
 }
 
