@@ -485,7 +485,12 @@ void KstDataWizard::showPage( QWidget *page )
       _newWindows->setEnabled(false);
       _currentWindow->setChecked(true);
     }
-    _multiplePlots->setChecked(true);
+
+    //
+    // don't automatically select _multiplePlots as we
+    //  want to remember what the user last selected...
+    //
+    // _multiplePlots->setChecked(true);
 
     updateWindowBox();
     updatePlotBox();
@@ -588,8 +593,8 @@ void KstDataWizard::updatePlotBox()
     _existingPlotName->setEnabled(havePlots && _existingPlot->isChecked());
   }
 
-  if (!_plotGroup->selected()->isEnabled()) {
-    _onePlot->setChecked(true);
+  if (!_plotGroup->selected() || !_plotGroup->selected()->isEnabled()) {
+    _multiplePlots->setChecked(true);
   }
 
   if (_existingPlot->isEnabled() && _existingPlotName->listBox() && _existingPlotName->listBox()->findItem(psave)) {
