@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef KSTGFXRECTANGLEMOUSEHANDLER_H
-#define KSTGFXRECTANGLEMOUSEHANDLER_H
+#ifndef KSTGFX2DPLOTMOUSEHANDLER_H
+#define KSTGFX2DPLOTMOUSEHANDLER_H
 
 #include "kstgfxmousehandler.h"
 
