@@ -90,6 +90,37 @@ KstMatrixDialogI::KstMatrixDialogI(QWidget* parent, const char* name, bool modal
   connect(_w->_doSkip, SIGNAL(clicked()), this, SLOT(setDoSkipDirty()));
   connect(_w->_doAve, SIGNAL(clicked()), this, SLOT(setDoAveDirty()));
 
+  // for apply button
+  connect(_w->_fileName, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_field, SIGNAL(highlighted(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_configure, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_xStart, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yStart, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xNumSteps, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yNumSteps, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xStart->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yStart->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xNumSteps->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yNumSteps->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xStartCountFromEnd, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_yStartCountFromEnd, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_xNumStepsReadToEnd, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_yNumStepsReadToEnd, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_doSkip, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_skip, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_skip->child("qt_spinbox_edit"), SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_doAve, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_gradientX, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_gradientY, SIGNAL(clicked()), this, SLOT(wasModifiedApply()));
+  connect(_w->_gradientZAtMin, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_gradientZAtMax, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_nX, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_nY, SIGNAL(valueChanged(int)), this, SLOT(wasModifiedApply()));
+  connect(_w->_minX, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_minY, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_xStep, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+  connect(_w->_yStep, SIGNAL(textChanged(const QString&)), this, SLOT(wasModifiedApply()));
+
   adjustSize();
   resize(minimumSizeHint());
   setFixedHeight(height());
@@ -395,8 +426,10 @@ bool KstMatrixDialogI::new_ISMatrix() {
   if (!checkParameters(ok3, ok4, ok5, ok6, xStep, yStep)) {
     return false;
   }
+
   if (!ok1 || !ok2) {
     KMessageBox::sorry(this, i18n("Invalid gradient bounds.  Ensure only decimal values are entered."));
+
     return false;
   }
 
@@ -406,6 +439,7 @@ bool KstMatrixDialogI::new_ISMatrix() {
   emit matrixCreated(KstMatrixPtr(matrix));
   matrix = 0L; // drop the reference
   emit modified();
+
   return true;
 }
 
@@ -422,8 +456,9 @@ bool KstMatrixDialogI::editSingleRMatrix(KstRMatrixPtr rmp) {
   // get the parameters for this object
   KstDataSourcePtr file;
   QString pField;
+
   if (_fileNameDirty) {
-    /* if there is not an active KstFile, create one */
+    // if there is not an active KstFile, create one
     KST::dataSourceList.lock().writeLock();
     KstDataSourceList::Iterator it = KST::dataSourceList.findReusableFileName(_w->_fileName->url());
 
@@ -457,41 +492,49 @@ bool KstMatrixDialogI::editSingleRMatrix(KstRMatrixPtr rmp) {
     pField = rmp->field();
     rmp->unlock();
   }
+
   int xStart, yStart, xNumSteps, yNumSteps;
   bool doSkip, doAve;
   int skip;
 
   rmp->readLock();
+
   if (_xStartDirty || _xStartCountFromEndDirty) {
     xStart = _w->_xStartCountFromEnd->isChecked() ? -1 : _w->_xStart->value();
   } else {
     xStart = rmp->reqXStart();
   }
+
   if (_yStartDirty || _yStartCountFromEndDirty) {
     yStart = _w->_yStartCountFromEnd->isChecked() ? -1 : _w->_yStart->value();
   } else {
     yStart = rmp->reqYStart();
   }
+
   if (_xNumStepsDirty || _xNumStepsReadToEndDirty) {
     xNumSteps = _w->_xNumStepsReadToEnd->isChecked() ? -1 : _w->_xNumSteps->value();
   } else {
     xNumSteps = rmp->reqXNumSteps();
   }
+
   if (_yNumStepsDirty || _yNumStepsReadToEndDirty) {
     yNumSteps = _w->_yNumStepsReadToEnd->isChecked() ? -1 : _w->_yNumSteps->value();
   } else {
     yNumSteps = rmp->reqYNumSteps();
   }
+
   if (_doSkipDirty) {
     doSkip = _w->_doSkip->isChecked();
   } else {
     doSkip = rmp->doSkip();
   }
+
   if (_doAveDirty) {
     doAve = _w->_doAve->isChecked();
   } else {
     doAve = rmp->doAverage();
   }
+
   if (_skipDirty) {
     skip = _w->_skip->value();
   } else {
@@ -503,18 +546,20 @@ bool KstMatrixDialogI::editSingleRMatrix(KstRMatrixPtr rmp) {
   rmp->writeLock();
   rmp->change(file, pField, KstObjectTag(rmp->tag().tag(), rmp->tag().context()), xStart, yStart, xNumSteps, yNumSteps, doAve, doSkip, skip);
   rmp->unlock();
+
   return true;
 }
 
 
 bool KstMatrixDialogI::editSingleSMatrix(KstSMatrixPtr smp) {
-  bool xDirection, ok5, ok6;
   double gradientZAtMin, gradientZAtMax;
-  int nX, nY;
   double xMin, yMin, xStepSize, yStepSize;
   bool ok1 = true, ok2 = true, ok3 = true, ok4 = true;
+  bool xDirection, ok5 = true, ok6 = true;
+  int nX, nY;
 
   smp->readLock();
+
   if (_xStepDirty) {
     xStepSize = _w->_xStep->text().toDouble(&ok1);
   } else {
@@ -544,32 +589,38 @@ bool KstMatrixDialogI::editSingleSMatrix(KstSMatrixPtr smp) {
   } else {
     xDirection = smp->xDirection();
   }
+
   if (_gradientZAtMinDirty) {
     gradientZAtMin = _w->_gradientZAtMin->text().toDouble(&ok5);
   } else {
     gradientZAtMin = smp->gradZMin();
   }
+
   if (_gradientZAtMaxDirty) {
     gradientZAtMax = _w->_gradientZAtMax->text().toDouble(&ok6);
   } else {
     gradientZAtMax = smp->gradZMax();
   }
+
   if (_nXDirty) {
     nX = _w->_nX->value();
   } else {
     nX = smp->xNumSteps();
   }
+
   if (_nYDirty) {
     nY = _w->_nY->value();
   } else {
     nY = smp->yNumSteps();
   }
+
   smp->unlock();
+
   if (!ok5 || !ok6) {
     KMessageBox::sorry(this, i18n("Gradient values are invalid.  Ensure only decimal values are entered."));
     return false;
   }
-  // check the other parameters
+
   if (!checkParameters(ok1, ok2, ok3, ok4, xStepSize, yStepSize)) {
     return false;
   }
@@ -681,21 +732,24 @@ bool KstMatrixDialogI::editObject() {
       return false;
     }
   }
+
   emit modified();
+
   return true;
 }
 
 
 bool KstMatrixDialogI::checkParameters(bool ok1, bool ok2, bool ok3, bool ok4, double xStep, double yStep) {
-    //check parameters
   if (!(ok1 && ok2 && ok3 && ok4)) {
     KMessageBox::sorry(this, i18n("One or more grid parameters have invalid values.  Ensure that only decimal values are entered."));
     return false;
   }
+
   if (xStep <= 0 || yStep <= 0) {
     KMessageBox::sorry(this, i18n("Invalid step size entered.  Ensure the step sizes are positive."));
     return false;
   }
+
   return true;
 }
 
@@ -1042,4 +1096,3 @@ KstObjectPtr KstMatrixDialogI::findObject(const QString& name) {
 }
 
 #include "kstmatrixdialog_i.moc"
-// vim: ts=2 sw=2 et
