@@ -20,6 +20,7 @@
 #include <math.h>
 
 // include files for Qt
+#include <qstylesheet.h>
 
 // include files for KDE
 #include "ksdebug.h"
@@ -81,6 +82,7 @@ KstTopLevelView::KstTopLevelView(const QDomElement& e, QWidget *parent, const ch
 void KstTopLevelView::commonConstructor() {
   _type = "TopLevelView";
   _editTitle = i18n("Edit View");
+  _newTitle = i18n("New View");
   _focusOn = false;
   _pressDirection = -1;
   _moveOffset = QPoint(-1, -1);
@@ -145,7 +147,7 @@ void KstTopLevelView::save(QTextStream& ts, const QString& indent) {
 
   for (int i = 0; i < metaObject()->numProperties(true); i++) {
     ts << indent << "<" << metaObject()->property(i, true)->name() << ">";
-    ts << property(metaObject()->property(i, true)->name()).toString().latin1();
+    ts << QStyleSheet::escape(property(metaObject()->property(i, true)->name()).toString().latin1());
     ts << "</" << metaObject()->property(i, true)->name() << ">" << endl;
   }
 
@@ -1874,7 +1876,9 @@ KstViewWidget *KstTopLevelView::widget() const {
 
 
 void KstTopLevelView::cleanupDefault() {
+  //
   // roughly layout in a square
+  //
   cleanup(-1);
 }
 
@@ -1958,7 +1962,7 @@ void KstTopLevelView::restoreDefaults(KstViewObjectPtr object) {
 bool KstTopLevelView::handleDoubleClick(const QPoint& pos, bool shift) {
   handlePress(pos, shift);
   if (_pressTarget) {
-    _pressTarget->showDialog(this, false);  
+    _pressTarget->showDialog(this, false);
   }
 
   return true;
@@ -2036,14 +2040,14 @@ QRect KstTopLevelView::correctHeightForRatio(const QRect& oldRect, double ratio,
         if (negOneW < 0) {
           if (direction & RIGHT) {
             r.setLeft(origLeft - (origRight-origLeft));
-            r.setRight(origLeft);  
+            r.setRight(origLeft);
           } else {
             r.setLeft(origRight + (origRight - origLeft));
-            r.setRight(origRight);  
+            r.setRight(origRight);
           }
         } else {
           r.setLeft(origLeft);
-          r.setRight(origRight);  
+          r.setRight(origRight);
         } 
       }
     } else if (direction & DOWN) {
@@ -2053,14 +2057,14 @@ QRect KstTopLevelView::correctHeightForRatio(const QRect& oldRect, double ratio,
         if (negOneW < 0) {
           if (direction & RIGHT) {
             r.setLeft(origLeft - (origRight-origLeft));
-            r.setRight(origLeft);  
+            r.setRight(origLeft);
           } else {
             r.setLeft(origRight + (origRight - origLeft));
-            r.setRight(origRight);  
+            r.setRight(origRight);
           }
         } else {
           r.setLeft(origLeft);
-          r.setRight(origRight);  
+          r.setRight(origRight);
         }
       }
     } else {
@@ -2161,6 +2165,34 @@ QMap<QString, QVariant > KstTopLevelView::widgetHints(const QString& propertyNam
   if (propertyName == "backgroundColor") {
     map.insert(QString("_kst_widgetType"), QString("KColorButton"));
     map.insert(QString("_kst_label"), i18n("Background color"));
+  } else if (propertyName == "marginLeft") {
+    map.insert(QString("_kst_widgetType"), QString("KDoubleSpinBox"));
+    map.insert(QString("_kst_label"), i18n("Left margin"));
+    map.insert(QString("minValue"), 0.0);
+    map.insert(QString("maxValue"), 0.5);
+    map.insert(QString("lineStep"), 0.01);
+    map.insert(QString("precision"), 2);
+  } else if (propertyName == "marginRight") {
+    map.insert(QString("_kst_widgetType"), QString("KDoubleSpinBox"));
+    map.insert(QString("_kst_label"), i18n("Right margin"));
+    map.insert(QString("minValue"), 0.0);
+    map.insert(QString("maxValue"), 0.5);
+    map.insert(QString("lineStep"), 0.01);
+    map.insert(QString("precision"), 2);
+  } else if (propertyName == "marginTop") {
+    map.insert(QString("_kst_widgetType"), QString("KDoubleSpinBox"));
+    map.insert(QString("_kst_label"), i18n("Top margin"));
+    map.insert(QString("minValue"), 0.0);
+    map.insert(QString("maxValue"), 0.5);
+    map.insert(QString("lineStep"), 0.01);
+    map.insert(QString("precision"), 2);
+  } else if (propertyName == "marginBottom") {
+    map.insert(QString("_kst_widgetType"), QString("KDoubleSpinBox"));
+    map.insert(QString("_kst_label"), i18n("Bottom margin"));
+    map.insert(QString("minValue"), 0.0);
+    map.insert(QString("maxValue"), 0.5);
+    map.insert(QString("lineStep"), 0.01);
+    map.insert(QString("precision"), 2);
   }
 
   return map;
