@@ -340,7 +340,7 @@ void KstDataObject::unlock() const {
 }
 
 
-void KstDataObject::writeLockInputsAndOutputs() const {
+void KstDataObject::writeLockInputsAndOutputs() {
   Q_ASSERT(myLockStatus() == KstRWLock::WRITELOCKED);
 
   #ifdef LOCKTRACE
@@ -392,6 +392,7 @@ void KstDataObject::writeLockInputsAndOutputs() const {
   QValueList<KstPrimitivePtr>::ConstIterator inputIt = inputs.begin();
   QValueList<KstPrimitivePtr>::ConstIterator outputIt = outputs.begin();
 
+  _mutexLock.lock();
   while (inputIt != inputs.end() || outputIt != outputs.end()) {
     if (inputIt != inputs.end() && (outputIt == outputs.end() || (void*)(*inputIt) < (void*)(*outputIt))) {
       // do input
@@ -411,13 +412,14 @@ void KstDataObject::writeLockInputsAndOutputs() const {
 #ifdef LOCKTRACE
       kstdDebug() << (void*)this << " (" << this->type() << ": " << this->tag().tagString() << ") KstDataObject::writeLockInputsAndOutputs() by tid=" << (int)QThread::currentThread() << ": write locking output \"" << (*outputIt)->tag().tagString() << "\" (" << (void*)((KstRWLock*)*outputIt) << ")" << endl;
 #endif
-      if ((*outputIt)->provider() != this) {
+      if ((*outputIt)->provider() != KstObjectPtr(this)) {
         KstDebug::self()->log(i18n("(%1) KstDataObject::writeLockInputsAndOutputs() by tid=%2: write locking output %3 (not provider) -- this is probably an error. Please email kst@kde.org with details.").arg(this->type()).arg((int)QThread::currentThread()).arg((*outputIt)->tagName()), KstDebug::Error);
       }
       (*outputIt)->writeLock();
       ++outputIt;
     }
   }
+  _mutexLock.unlock();
 }
 
 
