@@ -135,8 +135,8 @@ class KST_EXPORT KstDataObject : public KstObject {
     void setVersion(const QString& str) { _version = str; }
     void setLibrary(const QString& str) { _library = str; }
 
-    virtual void writeLockInputsAndOutputs() const;
-    virtual void unlockInputsAndOutputs() const;
+    virtual void writeLockInputsAndOutputs();
+    virtual void unlockInputsAndOutputs()const;
 
     KstVectorMap _inputVectors;
     KstVectorMap _outputVectors;
@@ -148,6 +148,7 @@ class KST_EXPORT KstDataObject : public KstObject {
     KstMatrixMap _outputMatrices;
 
     QString _typeString, _type;
+    QMutex  _mutexLock;
 
     bool _isInputLoaded;
     bool _isRecursed : 1;
