@@ -950,13 +950,12 @@ KstDataObjectPtr KstVCurve::makeDuplicate(KstDataObjectDataObjectMap& duplicated
 void KstVCurve::paint(const KstCurveRenderContext& context) {
   KstVectorPtr xv = *_inputVectors.find(COLOR_XVECTOR);
   KstVectorPtr yv = *_inputVectors.find(COLOR_YVECTOR);
+
   if (!xv || !yv) {
     return;
   }
 
   KstPainter *p = context.p;
-  KstReadLocker xvLocker(xv);
-  KstReadLocker yvLocker(yv);
   QColor foregroundColor = context.foregroundColor;
   double Lx = context.Lx;
   double Hx = context.Hx;
@@ -1000,7 +999,30 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
   }
 
   int pointDim = KstCurvePointSymbol::dim(p);
+
   if (sampleCount() > 0) {
+    _mutexLock.lock();
+    KstReadLocker xvLocker(xv);
+    KstReadLocker yvLocker(yv);
+    KstVectorPtr exv = *_inputVectors.find(EXVECTOR);
+    KstVectorPtr eyv = *_inputVectors.find(EYVECTOR);
+    KstVectorPtr exmv = *_inputVectors.find(EXMINUSVECTOR);
+    KstVectorPtr eymv = *_inputVectors.find(EYMINUSVECTOR);
+
+    if (exv) {
+      exv->readLock();
+    }
+    if (eyv) {
+      eyv->readLock();
+    }
+    if (exmv) {
+      exmv->readLock();
+    }
+    if (eymv) {
+      eymv->readLock();
+    }
+    _mutexLock.unlock();
+
     Qt::PenStyle style = KstLineStyle[lineStyle()];
     int i0, iN;
     int width;
@@ -1319,24 +1341,6 @@ void KstVCurve::paint(const KstCurveRenderContext& context) {
     benchmark0 = benchtmp.elapsed();
 #endif
 
-    KstVectorPtr exv = *_inputVectors.find(EXVECTOR);
-    KstVectorPtr eyv = *_inputVectors.find(EYVECTOR);
-    KstVectorPtr exmv = *_inputVectors.find(EXMINUSVECTOR);
-    KstVectorPtr eymv = *_inputVectors.find(EYMINUSVECTOR);
-
-    if (exv) {
-      exv->readLock();
-    }
-    if (eyv) {
-      eyv->readLock();
-    }
-    if (exmv) {
-      exmv->readLock();
-    }
-    if (eymv) {
-      eymv->readLock();
-    }
-
     // draw the bargraph bars, if any...
     if (hasBars()) {
       bool has_top = true;
