@@ -54,14 +54,9 @@ bool CrossCorrelate::algorithm() {
 
   double* pdArrayOne;
   double* pdArrayTwo;
-  double* pdResult[2];
-  double  dReal;
-  double  dImag;
-
-  int iLength;
-  int iLengthNew;
-
-  bool iReturn = false;
+  int     iLength;
+  int     iLengthNew;
+  bool    bReturn = false;
 
   //
   // zero-pad the array...
@@ -86,65 +81,99 @@ bool CrossCorrelate::algorithm() {
   }
 
   pdArrayOne = new double[iLength];
-  pdArrayTwo = new double[iLength];
-  if (pdArrayOne != NULL && pdArrayTwo != NULL) {
-    double sigmaSquared = 0.0;
+  if (pdArrayOne != NULL) {
+    pdArrayTwo = new double[iLength];
+    if (pdArrayTwo != NULL) {
+      double  sigmaSquaredOne = 0.0;
+      double  sigmaSquaredTwo = 0.0;
+      double  sigmaSquared;
+      double  meanOne = 0.0;
+      double  meanTwo = 0.0;
+      int     numOne = 0;
+      int     numTwo = 0;
 
-    //
-    // zero-pad the two arrays...
-    //
-    memset( pdArrayOne, 0, iLength * sizeof( double ) );
-    memcpy( pdArrayOne, array_one->value(), array_one->length() * sizeof( double ) );
+      //
+      // zero-pad the two arrays...
+      //
+      memset( pdArrayOne, 0, iLength * sizeof( double ) );
+      memcpy( pdArrayOne, array_one->value(), array_one->length() * sizeof( double ) );
 
-    memset( pdArrayTwo, 0, iLength * sizeof( double ) );
-    memcpy( pdArrayTwo, array_two->value(), array_two->length() * sizeof( double ) );
+      memset( pdArrayTwo, 0, iLength * sizeof( double ) );
+      memcpy( pdArrayTwo, array_two->value(), array_two->length() * sizeof( double ) );
 
-    //
-    // determine the scaling factor...
-    //
-    for (int i=0; i<array_one->length(); i++) {
-      sigmaSquared += pdArrayOne[i] * pdArrayOne[i];
-      sigmaSquared += pdArrayTwo[i] * pdArrayTwo[i];
-    }
-    sigmaSquared /= 2.0;
+      //
+      // determine the mean for each of the two data sets...
+      //
+      for (int i=0; i<array_one->length(); i++) {
+        if (pdArrayOne[i] == pdArrayOne[i]) {
+          meanOne += pdArrayOne[i];
+          numOne++;
+        }
+        if (pdArrayTwo[i] == pdArrayTwo[i]) {
+          meanTwo += pdArrayTwo[i];
+          numTwo++;
+        }
+      }
 
-    //
-    // calculate the FFTs of the two functions...
-    //
-    if (gsl_fft_real_radix2_transform( pdArrayOne, 1, iLength ) == 0) {
-      if (gsl_fft_real_radix2_transform( pdArrayTwo, 1, iLength ) == 0) {
-        //
-        // multiply one FFT by the complex conjugate of the other...
-        //
-        for (int i=0; i<iLength/2; i++) {
-          if (i==0 || i==(iLength/2)-1) {
-            pdArrayOne[i] = pdArrayOne[i] * pdArrayTwo[i];
-          } else {
-            dReal = pdArrayOne[i] * pdArrayTwo[i] + pdArrayOne[iLength-i] * pdArrayTwo[iLength-i];
-            dImag = pdArrayOne[i] * pdArrayTwo[iLength-i] - pdArrayOne[iLength-i] * pdArrayTwo[i];
+      if (numOne > 0) {
+        meanOne /= (double)numOne;
+      }
 
-            pdArrayOne[i] = dReal;
-            pdArrayOne[iLength-i] = dImag;
-          }
+      if (numTwo > 0) {
+        meanTwo /= (double)numTwo;
+      }
+
+      //
+      // set Nan values to zero and remove the mean from each of the two data sets...
+      //
+      for (int i=0; i<array_one->length(); i++) {
+        if (pdArrayOne[i] == pdArrayOne[i]) {
+          pdArrayOne[i] -= meanOne;
+          sigmaSquaredOne += pdArrayOne[i] * pdArrayOne[i];
+        } else {
+          pdArrayOne[i] = 0.0;
         }
 
-        //
-        // do the inverse FFT...
-        //
-        if (gsl_fft_halfcomplex_radix2_inverse( pdArrayOne, 1, iLength ) == 0) {
-          if (step_value->length() != array_one->length()) {
-            pdResult[0] = (double*)realloc( step_value->value(), array_one->length() * sizeof( double ) );
-          } else {
-            pdResult[0] = step_value->value();
+        if (pdArrayTwo[i] == pdArrayTwo[i]) {
+          pdArrayTwo[i] -= meanTwo;
+          sigmaSquaredTwo += pdArrayTwo[i] * pdArrayTwo[i];
+        } else {
+          pdArrayTwo[i] = 0.0;
+        }
+      }
+
+      //
+      // determine the scaling factor...
+      //
+      sigmaSquared = sqrt( sigmaSquaredOne * sigmaSquaredTwo );
+
+      //
+      // calculate the FFTs of the two functions...
+      //
+      if (gsl_fft_real_radix2_transform( pdArrayOne, 1, iLength ) == 0) {
+        if (gsl_fft_real_radix2_transform( pdArrayTwo, 1, iLength ) == 0) {
+          double  dReal;
+          double  dImag;
+
+          //
+          // multiply one FFT by the complex conjugate of the other...
+          //
+          for (int i=0; i<iLength/2; i++) {
+            if (i==0 || i==(iLength/2)-1) {
+              pdArrayOne[i] = pdArrayOne[i] * pdArrayTwo[i];
+            } else {
+              dReal = pdArrayOne[i] * pdArrayTwo[i] + pdArrayOne[iLength-i] * pdArrayTwo[iLength-i];
+              dImag = pdArrayOne[i] * pdArrayTwo[iLength-i] - pdArrayOne[iLength-i] * pdArrayTwo[i];
+
+              pdArrayOne[i] = dReal;
+              pdArrayOne[iLength-i] = dImag;
+            }
           }
 
-          if (correlated->length() != array_two->length()) {
-            pdResult[1] = (double*)realloc( correlated->value(), array_two->length() * sizeof( double ) );
-          } else {
-            pdResult[1] = correlated->value();
-          }
-
-          if (pdResult[0] != NULL && pdResult[1] != NULL) {
+          //
+          // do the inverse FFT...
+          //
+          if (gsl_fft_halfcomplex_radix2_inverse( pdArrayOne, 1, iLength ) == 0) {
             memcpy( &(correlated->value()[array_one->length() / 2]),
                     &(pdArrayOne[0]),
                     ( ( array_one->length() + 1 ) / 2 ) * sizeof( double ) );
@@ -153,22 +182,26 @@ bool CrossCorrelate::algorithm() {
                     &(pdArrayOne[iLength - (array_one->length() / 2)]),
                     ( array_one->length() / 2 ) * sizeof( double ) );
 
+            //
+            // apply the scaling factor and set the step values...
+            //
             for (int i = 0; i < array_one->length(); i++) {
               correlated->value()[i] /= sigmaSquared;
               step_value->value()[i] = (double)( i - ( array_one->length() / 2 ) );
             }
 
-            iReturn = true;
+            bReturn = true;
           }
         }
       }
+
+      delete[] pdArrayTwo;
     }
+
+    delete[] pdArrayOne;
   }
 
-  delete[] pdArrayOne;
-  delete[] pdArrayTwo;
-
-  return iReturn;
+  return bReturn;
 }
 
 
