@@ -298,8 +298,10 @@ void CrossPowerSpectrum::crossspectrum() {
   double *a, *b;
   double sampleRate = sample->value();
   double df;
+  double dv;
   int i, xpsLen;
-  int dv0, dv1, vLen;
+  int vLen;
+  int v1Len, v2Len;
   int iSubset, nSubsets;
   int iSamp, copyLen;
 
@@ -317,10 +319,22 @@ void CrossPowerSpectrum::crossspectrum() {
   }
   xpsLen = int(pow( 2.0, xpsLen ));
 
+  v1Len = v1->length();
+  v2Len = v2->length();
+
   // input vector lengths
-  vLen = (v1->length() < v2->length()) ? v1->length() : v2->length();
-  dv0 = vLen/v1->length();
-  dv1 = vLen/v2->length();
+  vLen = (v1Len < v2Len) ? v1Len : v2Len;
+  if (vLen == 0) {
+    return;
+  }
+
+  if (v1Len == v2Len) {
+    dv = 1.0;
+  } else if (v1Len < v2Len) {
+    dv = (double)vLen / (double)v2Len;
+  } else {
+    dv = (double)vLen / (double)v1Len;
+  }
 
   while (xpsLen > vLen) {
     xpsLen /= 2;
@@ -361,10 +375,31 @@ void CrossPowerSpectrum::crossspectrum() {
     }
 
     for (iSamp = 0; iSamp < copyLen; iSamp++) {
-      i = ( iSamp + iSubset*xpsLen ) / dv0;
-      meanA += (a[iSamp] = v1->value()[i]);
-      i = ( iSamp + iSubset*xpsLen ) / dv1;
-      meanB += (b[iSamp] = v2->value()[i]);
+      if (v1Len == v2Len) {
+        i = iSamp + iSubset*xpsLen;
+        meanA += (a[iSamp] = v1->value()[i]);
+        meanB += (b[iSamp] = v2->value()[i]);
+      } else if (v1Len < v2Len) {
+        i = iSamp + iSubset*xpsLen;
+        meanA += (a[iSamp] = v1->value()[i]);
+
+        i = (int)( (double)( iSamp + iSubset*xpsLen ) / dv );
+        if (i < v2Len) {
+          meanB += (b[iSamp] = v2->value()[i]);
+        } else {
+          b[iSamp] = 0.0;
+        }
+      } else {
+        i = (int)( (double)( iSamp + iSubset*xpsLen ) / dv );
+        if (i < v1Len) {
+          meanA += (a[iSamp] = v1->value()[i]);
+        } else {
+          a[iSamp] = 0.0;
+        }
+
+        i = iSamp + iSubset*xpsLen;
+        meanB += (b[iSamp] = v2->value()[i]);
+      }
     }
 
     if (copyLen > 1) {
