@@ -61,6 +61,11 @@ CrossSpectrumDialogI::CrossSpectrumDialogI(QWidget* parent, const char* name, bo
   connect(_w->_sample, SIGNAL(newScalarCreated()), this, SIGNAL(modified()));
   connect(KstApp::inst()->document(), SIGNAL(updateDialogs()), this, SLOT(update()));
 
+  //
+  // without the following the instance is never deleted...
+  //
+  setWFlags(Qt::WDestructiveClose);
+
   _w->_fft->allowDirectEntry( true );
   _w->_sample->allowDirectEntry( true );
 }
@@ -134,6 +139,8 @@ bool CrossSpectrumDialogI::newObject() {
   KST::dataObjectList.append(cps.data());
   KST::dataObjectList.lock().unlock();
   cps = 0L; // drop the reference
+
+  disconnect(KstApp::inst()->document(), SIGNAL(updateDialogs()), this, SLOT(update()));
   emit modified();
 
   return true;
@@ -179,7 +186,9 @@ bool CrossSpectrumDialogI::editObject() {
   cps->unlock();
   cps->setDirty();
 
+  disconnect(KstApp::inst()->document(), SIGNAL(updateDialogs()), this, SLOT(update()));
   emit modified();
+
   return true;
 }
 
