@@ -24,6 +24,15 @@ bool interpolate(KstVectorPtr x_array,
   bool iReturn = false;
   double* pResult[1];
 
+  //
+  // the input x-vector must be monotonically increasing, 
+  // else we are not requesting something sensible and gsl 
+  // will choke on the request...
+  //
+  if (!x_array->isRising()) {
+    return false;
+  }
+
   iLengthData = x_array->length();
   if (y_array->length() < iLengthData) {
     iLengthData = y_array->length();
