@@ -132,7 +132,7 @@ void VectorSelector::setSelection( KstVectorPtr v )
 {
   if (v) {
     v->readLock();
-    setSelection(v->tag().tagString());
+    setSelection(v->tagName());
     v->unlock();
   } else if (_provideNoneVector) {
     setSelection(tr("<None>"));
