@@ -92,7 +92,7 @@ QDomDocument makeDOMElem(const QString& tag, const int nx, const int ny, const d
 
 void doTests() {
   bool ok = true;
-  
+
   QDomNode n = makeDOMElem("smDOM", 0, 0, 0, 0, 1, 1, 1, 1, true).firstChild();
   QDomElement e = n.toElement();
 
@@ -201,9 +201,13 @@ void doTests() {
 
 
 int main(int argc, char **argv) {
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
+
   atexit(exitHelper);
 
-  KApplication app(argc, argv, "testsmatrix", false, false);
+  KCmdLineArgs::init(argc, argv, "testsmatrix", "testsmatrix", "testsmatrix", "1.0.0.0");
+  KApplication app(false, false);
 
   doTests();
   // Don't put tests in main because we need to ensure that no KstObjects
